export function cowSwapBackground(darkMode: boolean, shouldBlurBackground: boolean): string {
  const blurFilter = shouldBlurBackground ? 'filter="url(#blurFilter)"' : ''
  const image = `<svg viewBox="0 0 2132.13 1200" width="2132.13" height="1200" xmlns="http://www.w3.org/2000/svg">
  <defs>
    <clipPath id="clip-path">
      <path fill="none" d="M0 0h2132.13v1200H0z"/>
    </clipPath>
    <style>
      #SUN {
        fill: rgb(255, 241, 62);
        animation: sun-move-in 1s linear alternate; 
      }
      @keyframes sun-move-in {
        from {  transform: translateY(-30%);}
        to { transform: translateY(0);}
      }

      #CLOUDS {
        fill: ${darkMode ? '#265195' : 'rgb(239, 248, 253)'}
      }

      #GRASS_BG {
        fill: ${darkMode ? '#144769' : '#9ad8c2'}
      }

      .GRASS_POOL {
        fill: ${darkMode ? '#1b5a7a' : 'rgb(98, 161, 141)'}
      }

      .GRASS_DARKER {
        fill: ${darkMode ? '#032744' : 'rgb(108, 177, 140)'}
      }

      .COW_DARK_SPOTS {
        fill: ${darkMode ? '#032744' : 'rgb(152, 116, 90)'}
      }

      .COW_DARK_SPOTS_2 {
        fill: ${darkMode ? '#032744' : '#000000'}
      }

      .COW_BODY {
        fill: ${darkMode ? '#c5daef' : 'rgb(255, 255, 255)'}
      }

      .DARK_TREE {
        fill: ${darkMode ? '#204984' : 'rgb(53, 109, 89)'}
      }

      .TRUNK_TREE {
        fill: ${darkMode ? '#032744' : 'rgb(183, 159, 136)'}
      }

      .DARK_TREE_2 {
        fill: ${darkMode ? '#265195' : 'rgb(81, 135, 117)'}
      }

      .BARN_DOORS {
        fill: ${darkMode ? '#ede17b' : 'rgb(93, 37, 14)'}
      }

      .BROWN_WOOD {
        fill: ${darkMode ? '#032744' : 'rgb(144, 103, 57)'}
      }

      .BARN_BUILDOUT_WOOD {
        fill: ${darkMode ? '#543414' : 'rgb(176, 126, 73)'}
      }

      .OWL {
        fill: ${darkMode ? '#032744' : 'rgb(94, 79, 69)'}
      }

      .BARN_WOOD {
        fill: ${darkMode ? '#491307' : 'rgb(200, 55, 14)'}
      }

      .BARN_BUILDOUT_WOOD_2 {
        fill: ${darkMode ? '#491307' : 'rgb(93, 37, 14)'}
      }

      .BARN_THIN_LINE {
        fill: ${darkMode ? '#7f2718' : '#f76e63'}
      }

      .BRIGHT_TREE {
        fill: ${darkMode ? '#265195' : 'rgb(67, 137, 114)'}
      }

      .COW_DARK_LEGS{
        fill: ${darkMode ? '#3b709b' : 'rgb(203, 219, 224)'}
      }

      .WINDPOLE_RADIAL {
        fill: ${darkMode ? '#032744' : 'rgb(176, 126, 73)'}
      }

      #LASER_EYES_LEFT {
        transition: all 0.5s ease-in-out;
      }

      #LASER_EYES_RIGHT {
        transition: all 0.5s ease-in-out;
        
      }

      @keyframes flickerLaser {
        0%, 19.999%, 22%, 62.999%, 64%, 64.999%, 70%, 100% {
          opacity: .99;
        }
        20%, 21.999%, 63%, 63.999%, 65%, 69.999% {
          opacity: 0.4;
      }

      #MOON {
      }

      #STARS_LEFT, #STARS_RIGHT {  
      }

    </style>
  </defs>
  
  <filter id="blurFilter">
    <feGaussianBlur in="SourceGraphic" stdDeviation="25" />
  </filter>

  <g clip-path="url(#clip-path)"
  ${blurFilter}>
  
    <!-- WIND POLE -->
    <!-- For dark theme with blur we hide the Wind pole to avoid ugly blur artifacts -->
    ${
      shouldBlurBackground && darkMode
        ? ''
        : `
    <path id="WINDPOLE_1" class="BROWN_WOOD" d="M364.39 480.48l2.8-.5-37.1-205.68a8.76 8.76 0 01-2.8 0L294.8 489.23h35.31V408.5h21.3zM317 361.22l4.82-31.81h5.43v31.81zm10.25 2.84v41.6h-17l6.29-41.6zm2.84-34.65h7l5.74 31.81h-12.72zm0-2.84v-36.14l6.52 36.14zm-2.84 0h-5l5-33.12zm0 159.82H298.1l11.78-77.89h17.39zm2.84-80.73v-41.6h13.28l7.51 41.6z"/>
    <path id="WINDPOLE_2" class="WINDPOLE_RADIAL" d="M324.11 277.74L305 288.43l3.46 5.26 12.06-9.86-10.19 11.95 5.07 3.73 11.32-19.27a5.07 5.07 0 01-2.61-2.5z"/>
    <path id="WINDPOLE_3" class="WINDPOLE_RADIAL" d="M356.55 277.91l-20.71-2.08 20.12-1.6L355 268l-18.8 4.9 17.27-9.66L350 258l-17.32 14.15L347 255.33l-5-3.73-9.67 16.45 5.16-18.26-6.16-1.27-2.19 21.82-1.75-22.07-6.22.94 5.06 19.5-9.57-17.11-5.25 3.46 12.5 15.3-15.46-13.16-3.73 5.06 19 11.14-20.49-5.79-1.28 6.16 17 1.71-17.56 1.4.94 6.22 21.67-5.63a5.1 5.1 0 013.95-7c5.76-1 8.16 7.59 2.79 9.72l11.1 19.86 5.26-3.46-11.5-14.08 13.32 11.37 3.73-5.07-18.1-10.63 20.74 5.86z"/>
    <path id="WINDPOLE_4" class="WINDPOLE_RADIAL" d="M327.08 280.37L321 301.88l6.16 1.28 1.6-15.94 1.24 15.62 6.22-.95-5.62-21.62a4.92 4.92 0 01-3.52.1zM330.6 280.27h.12l-.25-.44z"/>
    `
    }
    <!-- end - WIND POLE -->
    
    <path class="DARK_TREE" d="M576.27 416.43c-.95-.66-2.11-.54-3-1.21-1.28-.91-1.44-1.72-3.3-1.8-1.7-.07-1.88.35-3-.82-1.43-1.46-2.27-3.2-4.75-2.89-3.71 1.66-7.25-2.06-10.62 1-1.06 2-2 2.06-4.11 1.65-1.95.05-5.39 1-4.26 3.33-3.43-2.33-8.82 4.41-6.19 7.69.41 3 4 4.14 6.39 5 1.8.5 2.49 2.4 4.73 2.3a4.42 4.42 0 014.12.48c2.43-.43 2.12-.15 4 1.06 1.37.21 1.12-.91 2-1.32s.74-.14 1.79.55c2.91 1.91 5.53-.86 8-1.69 3-1 7.84-.51 8.15-5 2.44-1.56 2.45-6.64.05-8.33zM535.74 383.89c-.56-1.61-1-1.83-2.72-1.88.2-4.4 1.22-7.28-3.25-9.58-3-4.24-3.15-10.67-9.86-7.9-.79 0-1.53-.84-1.78.48-1.77.2-2.56-1.79-4-2.48-4.56-2.06-12 0-11.25 6 .93 2.24-2.21 2.78-3.9 2.74.18.39.19.81.58 1.15-3.1-1.43-8.73-.52-7.43 3.88.37.83 1.21.63.82 1.72-2.18 1.37-3.33 4-1.38 6.17-3.39 4.83-1.31 11 5 9.46 1.55-.56 1.71.22 3 .79.34 3.11 6.92 2.69 8.86 1.79a1.36 1.36 0 002 .7c-.24 3.35 6.15 2.43 7.64.93 1.69-1.7.36-6.15 2.66-6.76a3.37 3.37 0 00-.07.62c2.77.14 1.7-2 4.68.32 1.08.3 1.06-.21 2-.38 2.39-.47 9.81.57 6.86-4.37 1.9-.64 2.1-1.81 1.54-3.4z"/>
    <path class="DARK_TREE_2" d="M577.66 374.61c-.39-1.55-2.31-1.75-2-3.37.79-.73 2-2.28.17-3.06a7.9 7.9 0 00-7.62-9.33c-2.81-.5-5.38 1.73-7.15-1.12-1.31-.66-3-.06-3.32-1.94-3-1.8-14-6.7-12.29.59-3.58 1-11.35-5.41-11.84 1.8-3.52.65-10.84.36-9.16 6-9.51-.34-9.15 15.56-.66 15.88-1 2.45 1.29 2.5 2.35 3.85-1.47 3.32 6.65 5.73 7 2.32a1.57 1.57 0 011.47.33c3-3.6 4.22 1.15 2.82 3.63 0 2.86 3.95 3.69 5.85 2.07a6.19 6.19 0 008.3 1.29c.78 1.67 3.14 1.38 4.67 1.3-.37-1.65 1-.91 1.53-1.72-.41-6.18 5.71 1.74 7.36-3.06 1.83 0 3.11.32 3.61-1.74 3.85-.66 5.27-.78 4.22-5.1 4.03-.71 5.29-5.09 4.69-8.62z"/>
    <path class="TRUNK_TREE" d="M542.1 482.07c-11.78-17.92-2.87-37.55 10.5-51.64 4-3 9.3-3.87 13.08-6.8.8-.56 1.44-1 1.13-.92-4.44 2.84-9.89 3.77-14.39 6.56.8-3.95 4.1-11.85 4.75-14.59-3 5.92-4.68 13.42-8.75 19-4.31 4.73-8.29 10.05-12.06 14.77-3.45-11.07.93-23.23.84-34.45-1.52-18.95 4.65-39.37-.25-57.85-.05 1.53.38 3.71.33 5.67a260.94 260.94 0 01-2 28.65c-4.56-8-5.46-18.65-9.64-26.44.38 1.15.77 2.54 1.14 4.11-.47-.9-.82-1.53-.74-1.18a235.34 235.34 0 017.54 29c-.18 6.51-1.55 13.17-1.55 19.3-3.51-6.5-7.18-13.55-8.65-20.71-.43-5.94.2-15.91-1.12-20.69 1 7.69-.89 16.43.75 24.23a1.34 1.34 0 01-.28 0c-3.63-5.51-10-9.46-12.77-15.46-.5-.74-3.38-4.49-3-3.76 2.71 3.75 4.61 8.69 8 12.1 2.37 2.81 5.86 5.09 7.09 8.64 2.47 6.79 5.29 13.45 6.92 19.93a.27.27 0 000-.08c.88 20.6 3.94 44.44-3.52 63.91H543a15.33 15.33 0 01-.9-1.3z"/>
    
    <path class="BRIGHT_TREE" d="M536 357.48c.48-1.69-1.13-1-1.66-1.86s0-2.29-.57-3.3-5-4.21-5.12-1.47a2.13 2.13 0 01-.94 0c-.3-1.68 1.21-2.08-.66-3.16a3.55 3.55 0 00-2.17-.59c.5-6.09-10.61-6.68-11.06-.41-3.69-1.14-3.52 4.66-7.34-.46-6.75-2.77-3.87 3.81-7.22 3.76-2.45-.3-4.53-2.43-7.29-1.55-3.79 1.2-5.89 7.91-3.35 10.94-.91-.24-1.51.18-1.3 1.14-3.21-2.16-5.46 3.23-2.52 4.53-3.6-.67-4.07 5.05-3.3 7.3.6 1.76 1.84 2.21 3.39 2.69.88.27 1.11-.16 1.56.77a1.24 1.24 0 01-.73 1.87c-2.91-4.25-9 3.12-5 5.36-3.15 3.12 1.06 5.41 4.12 4.86 0 4.17 5.6 3.82 8.43 3.39 3.37 1.5 6.52-.86 6.79-4.4 4.13 1.29 4.35-1.92 6.88-2.92 3.2.33 4-1.93 5.6-4.11a1.12 1.12 0 001.82-.31 3.49 3.49 0 005.12-1.18c2.84-.87 6.35-2.95 3.94-6.34 1.6.17 6.35-1.78 4.1-3.82.75-.5.11-1 .51-1.5 1-1.15 4.7-1.35 3.19-3.55 2.32-1 6.67-.62 7.7-3.61.56-1.73-1.29-2.89-2.92-2.07z" />
    <path class="BRIGHT_TREE" d="M575.83 355.2c-.33-3-2.17-8.16-6-4.83-1.08-3.07-8.92-4.77-9-.67.17 1 1.33.84.83 2.17a1.84 1.84 0 01-2.33.83c-1.17-.83.33-1.33.17-2.16 0-1.17-1.17-.84-2-.5 0-1.34-1.5-4.84-3.34-2.84-.15-4.76-4.4-4.24-7.33-2.33a4.47 4.47 0 00-6.67-3.5c-1.33 1.17-.16 3.17-2.33 1.67-1.67-1.34-1.67-1.17-3 .33-2.91-4.64-11.48-4.72-13.33.83-.17.84.5 2.5-1 2.5-1.17-.16-1.5-1.66-3-1.66-2.34 0-4.84 2.33-3.17 4.5-6.45.41-5 11.08.37 12.53-1 3 .19 5 2.46 6.63-4.5-.33-5.5 8-.33 7.67-1.54 4.15 1.82 6.42 5.67 5.83 2-.5 1.83-2.5 3.5-3.16 2-.31 2.52-1.49 2.66-3.5 1.5.33 1.67-.34 2.84-1.17 5.79-.94-1.5-9.85 5.83-7.67 3.69-1.8 2.11-1.9 5.33.51 3.45 1.05 6.38-3.92 8.84.33a3.72 3.72 0 001.33 0c-1.17 3.83 5.17 5 7.67 4.16 3.44-1.5 7.52.4 10.5-2.5 2.16-1.83 1.33-4.83 3-6.83 3.6-2.81 3.44-3.02 1.83-7.17z" />
    
    <path class="DARK_TREE_2" d="M582.5 414.47c2.06-1.62.92-2.3-.17-4.16.34-2-.67-4-3-3.67-2.84 1.27-4.08.21-5.5-2.34-2.5-2.16-4 .67-6.17.51-2.57-1.26-2.08-5-5.66-1-.93-1.24-1.72-2.3-3.27-1.81-3.88-1.37-10-5.59-12.25.2a4.2 4.2 0 00-4.81 3.91h-.24c-.68-1.13-2.58-1.64-3.43-.54-1.78-2.2-3.93 1-3.7 2.79-2.38-.2-4.54.31-4.63 3-2.09 1-7.2 3.25-5.34 6.29 1.17 1.33 3.5.17 4.67 1.17 1.87 4.48.49 6.72 7.13 5.5a1.9 1.9 0 001.79.09 2.56 2.56 0 001.54 3.7c1.63.26 2.15-1.24 3.6-.49 2.9 2.39 5.07.48 4.76-3a2.1 2.1 0 003.13-1.18c.71 2.93 3.37.76 5.45-1.25a14.79 14.79 0 005.94-1.18c.1.59.43.88 1.59.74.36 2.47 2.71 3.08 4.49 1.66.13 1.78 2.46 2.18 4.3 1.85 2.46 3.48 8.42-1 9.74-3.77.16-1.33-.84-3.5-1.34-4.83.88-.35.88-1.52 1.38-2.19z"/>
   
    <path class="DARK_TREE" d="M859.62 374.18c1.4-2.62 2.77-6.63-.82-8.08-3.34-.17-3.61-.63-3.17-3.92-.75-9.83-12.56 3.07-12.52-2.32-1.32-.14-2.38 1.09-3.25-.46 4.17-7.46-8-8.73-12.41-5.67a2.76 2.76 0 00-1.61-.13c.11-1.39-1-4.68-2.71-4.53s-2.59 3.21-4.47 3.57c-2.48.48-1.35-1.83-2-3.2-3.44-5.18-12.56-1.24-11.14 4.9-5.36-.79-5.78 5.22-4.68 9.05.31.74 1.61 1.22 1 2.1-1.18 1.59-3.06-1.41-4.48.28-3.3 5.26 5.13 2.86 3.25 6.21-.55 1-3.25 2.12-4.15 1.25-.5-2.08-1.3-2.69-3.25-1.32-1.38 1-1.35 2.22-2.15 3.46-1.2 1.85-1.88 1.46-.6 3.53 2 3.19-3.22 2.26-3 5.18-2.35.41-4.64.58-5.43 3.12-.61 2-.54 3.53 1.61 4.09 1.51.4 3.17-.5 4.56.18 5.91 2.93-3.62 7.89 8.29 9.74 2.33.05 3.9-1.51 4.87-3.41 1.81-1.72 1.47.36 1.78 1.49.56 2 1.78.95 3.14 1.45 1.57 1.34 3.59 1.81 5.44.4 3.32 9.95 10.46-4.48 11 2.17 1.52.3 1.42.66 1.48 2.08 1.63.32 8.21-3.74 6.52.65-2 3.25 4.8 4.69 5 1.17a6.2 6.2 0 003.65.1c4-.79 6.78 2.63 7.89-3.06.81-.74 2.05-.05 3 0 6.32.24 3-8.25 4.66-11.62 9.54-13.63-7.29-4.76 4.7-18.45z" />
    <path class="TRUNK_TREE" d="M912.06 477.48c-5.4-7.1-6.92-15.91-2.8-23.62.56-3.47-.5-7 .33-10.5 1.15-4.53 1.54-9.56 4.77-13.2 4.58-4.92 5.76-11.83 8-18.15l-.58.16c-2.44 5.58-3.32 12.38-8.06 16.65-1.73 1.49-2.93 3.67-4.2 5.64-3.84-4.4-5.32-9.87-7-15.27l-.74-.17c.09.71.25 1.38.38 2.11.25 2.25 1.67 4.17 2 6.4.3 4.12 2.32 7.47 3.37 11.25.11 3.23-1.5 7-1.89 10.16-5.06 4.18-15.33-9.61-19.94-12.07-12.37.59-14.87-14.35-22.87-18.84-6.27-5.35-8.55-18.09 1.76-20.24 2.5-1 3.91-3.46 6.11-4.88 2.31-2.12 6.24-2.18 8.41-4.66 1.75-1.93 5.23-4.34 5.39-6.72-2.77 5.77-9.21 7.74-14.46 10.69-1.59.94-2.93 2.59-4.4 3.68-2.53 1.68-5.9 1.92-7.85 4.52.12-13.65 12.05-16.51 10.86-27 .55 6.85-6 10.86-9.21 16.28-.75-3.18-3.74-8.65-4.64-11.72a44.61 44.61 0 003.68 10.83c-.1 4.14-2 8.18-3.25 12.13a42 42 0 00-.53 9.5c-26.1-13.21-8.54-18.05-15.66-36.89 2.61 6.59.11 14.75-.43 22.06-2.57-2.44-2.81-6.28-5.49-8.62-3.69-3.22-4.76-7.42-7.37-11.38-.15-.16-.74-.57-.63-.38a6.33 6.33 0 011.79 3.18c-.35-.62-.57-1-.51-.74 1.52 4.38 4.35 8.08 7.28 11.6a47.89 47.89 0 004.31 7.85c1.38 2.18 1.59 5 3.75 6.72 8.9 8.45 15.14 18.95 25.11 26.72a15.68 15.68 0 012.79 3.83c.73 1.49 1.43 3.19 2.8 4.21 5 2.43 11.24 1.38 13.62 7.59 6 10.33 9.33 25.32.8 35.14h28.6a26.28 26.28 0 01-3.4-3.85z" />
    <path class="DARK_TREE_2" d="M917.38 395.15c-.58-1.68-2.85-.23-3.19-2.13-.16-.85.87-1.75.2-2.59a1.18 1.18 0 00-1.86 0c-1-3.48-4.8-4.65-8.2-4.25 1.42-4-.28-7.33-4.88-7.18-1 .17-2.17 1.78-3.11 1.37s-.35-1.84-1.73-1.79c.43-3.57-4.18-11-7.58-6.64-.41 1.25-.69 3-2.18 2a8.79 8.79 0 01.1-2.62 7.21 7.21 0 01-.79 0c.88-.66 1.3-1.5.09-2.46a3.6 3.6 0 00.38-6.59c-2.39-.5-3.51-1.09-2.56-3.7.71-4.05-3.18-4.66-6.26-5.17-2.75-1.38-5-5.6-8.67-3.82-.65.35-1.71 1.65-2.56 1.22-.61-.3-.44-1.37-1-1.81-1.84-.46-3-1.86-5-1.76-1.35.06-2.6.38-3.46-.88-.89-2-1.94-4.23-4.59-3.93-2.79-.48-1-5-5.93-2.67a2.61 2.61 0 00-2-.87c.05-7.72-13.23-6.59-12.1.79.14.81 1.32 2.74.78 3.52-3.37 1.61-7 1.17-4.56 6.44.21.54.69 1.3.22 1.86-1.65 1.37-1.33-1.78-2-2.38-1.31-.09-3-1.48-4.16-.59-2.92 2.41 4.57 11.36-3.12 8.15v.42c-2.85-1.54-4.7.63-4.77 3.56-.8 2.86 7.47 5 1.53 5.68-1.76-.23-3.8 1-2.1 2.62 1.5 2.48-4 .05-3 2.81-3 1.37-6 7.35-1.16 8.33 2.36 1.07 5.48-3.15 6.81-.23.14 2.48 1.25 4.25 3.85 4.73 2.8 1.14 5.25-.73 7.48-2.09-.06.43-.27.74-1.15.85-.16 1.29.75 1.82 1 2.91-2.69-.13-5.58 1.24-5.39 4.2-1 2.23-4.21 1.91-4.54 5 0 6.12 8.15 5.23 12.13 3.67 0 .33.26.63.21 1 .38 0 .71.27 1.13.19-.78 3.05 2.69 2.79 4.49 2 .28-.15 3.27-5.34 3.55-2.64 1 0 1.13.77 1 1.63 1.05.21.61 1 1 1.73 2.76 3.79 6-2.66 9.33-2 .76 2.34 3.86 2.65 5.93 2.85.94 1.36 1.79 1.58 3.4 2-.1 3 4.89 3.27 6.84 1.92 1.25-.86.17-1.76.72-2.59s2.12-.58 2.1.48c2.55-1.3 4.4-1.54 3.56 1.81.64 2.75 4.6-.33 5.85.12a2.08 2.08 0 003.22.56c6.52-3.48-3.17-6.69 2.28-10.42 1.63-.61 3.75.64 3.71 2.29 0 1-1.11 1.94.15 2.72.21-.3.66-.5.89-.78.53 1.51 2.48.19 3.2 1.46-.05 2.16 1.44 2.37 3.26 1.74 1.44-.6 1.53-1.42 3.2-1.6 1.24-.13 2.78-.2 3.55-1.4 1.13-1.78-1.4-2.44-.9-4.3 2.35-1 2.35 1.43 4.68.29a10.55 10.55 0 01-.1 2c2 .37 2.24-1.74 3.83-2.2 1.9.16 3.1-1 4.9-1.4 1 .06 4.86.88 4.05-1.44z" />
   
    <path id="GRASS_BG" d="M0 490.37l2133.23-14.33v734.25H0V490.37z"/>

    <path class="GRASS_POOL" d="M1931.27 546.31c-2.42-7.43-51.48-9.93-47.66-.3-9 .13-30.07 4.35-10.51 9 16.55 1.56-.17 4.71-7.42 4.77 0 9.74 31.91 7.78 36.36 3.28 1.16-3.57 28.14.53 10.24-8.08-3.85.29 2.44-.86 1.84-2.39-.03-3.52 14.88-.98 17.15-6.28zM1959 532.81c-1.82.13-1.74 1.18.08 1s1.79-1.15-.08-1zM1969.45 531c-1.82.13-1.74 1.18.08 1s1.74-1.17-.08-1zM1963.66 530.91c1.82-.13 1.74-1.17-.08-1s-1.75 1.16.08 1zM1975.66 533.07c-1.82.13-1.74 1.18.08 1s1.75-1.15-.08-1zM1954.77 530.83c0-.66-2.91-.44-2.81.22s2.91.43 2.81-.22zM1955.55 535.91c-1.83.13-1.74 1.18.08 1s1.75-1.15-.08-1zM1975.71 528.7c0-.67-2.91-.45-2.81.21s2.91.44 2.81-.21zM1959.74 526.84c-1.83.13-1.74 1.18.08 1s1.74-1.15-.08-1zM1947.36 533.2c-1.82.13-1.74 1.18.08 1s1.75-1.15-.08-1zM1983 531c-1.82.13-1.74 1.18.08 1s1.71-1.19-.08-1zM1968.54 537.48c-1.82.13-1.74 1.18.08 1s1.74-1.15-.08-1zM1964 534.75c-1.82.13-1.74 1.18.08 1s1.7-1.15-.08-1z"/>
    
    <path class="COW_DARK_SPOTS" d="M746.31 508.84c.8-1 0-1.82-.72-.66 0-1.86-4-1.62-4.67-.2-.89-1.28-1.38.18-.54.85-7.38-.83-14.61-1.83-22.12-2.33-5.23-.7-14.38-3.35-15.14 4.46-.94 4.47 2.28 9.87-1.91 13.24 1.25 3.06-3.69 13.29 2.8 11.07-4.15-3.77.94-9.74 3.94-13-.89 1.54-1.83 3.67-.12 5 1.14 2.45 1 9.4 5.21 7.39-3.46-4.62-3.3-8.21.13-12.61 9.63 6.16 7.88 1.86 16.81 2.85-1.34 1.08-1.44 3.37-1.91 4.92-1.66 2.2-3.27 6.1 1 5.6-.43-1.27-1.73-1.29-.25-2.93.21-2.26 2.41-3.18 3.06-5.22.45 1.32.59 3.24 1.52 4.33.23 2.13 1.47 6.17 4.2 4.46-1.61-1.54-3.25-4.41-2.29-6.75-1.49-5.77 4 4.72 8.14-9.85a1.83 1.83 0 001.75-.67l-.19-.21c1.47.27 1.42-6.34 1.71-7.58 1.64.39 3.82-.39 4-2.23-1.17-1.77-3.07.72-4.41.07zM1018.18 576.39c-.07-2.5-4.18-6.23-5.34-8.44-2.28-9.84-13.58-13.65-22.57-12.93-1.67 1.65-4.72 4.58-3.28 7.07 1.37 3.75-.66 9.39 3.4 11.63a8.08 8.08 0 001.17 6.46c-.25 1.54.56 8 2.84 5.17-1.68-3-1.42-6.54-.33-9.72 4.72.43.95 7.33 4.89 8.51 1.65-.72-.39-2.44-.42-3.61a14.15 14.15 0 01.05-3.95 25.35 25.35 0 011.41 7.82c-.2 1.25-.74 2.79.34 3.79.59 1.68 1.64 1.2 1.82-.34-.28-1.91-1-4.34.17-6.12.61-2-1.2-3.49-.45-5.62 2.14.65 3.41 4.72 6.19 3.21-.47 1.77.54 3.25 1.07 4.82-.18 2.16.67 6.26 3.61 5.17-2.2-3-2.67-6.39-2-10.2.46.25.94.58 1.28.81-1.93 3.5 2.6 6.51 2.65 9.65.05 1.38 1.72 1.74 2.84 1.64 1 .62 1.64-.12 1.9-1.12-.77-10.36 3.73-5.23.86-11.2 1.15-.14 2.66-1.49 2.24-2.76-1.38-.01-3.03 1.45-4.34.26zM487.5 500.78c-9.79.15-19 6-21.47 15.78-1.47 2.81-6.72 7.56-6.79 10.74-1.64 1.39-3.8-.28-5.48-.34-.54 1.63 1.36 3.32 2.84 3.51.06 1.11-1.54 2.48-1.42 3.72 4.68 4 .6 8.71 3.61 12.28 7.27-.77 3.09-1.71 6.14-5.7 1.53-2.46 3.71-6.11 2.18-9a8.34 8.34 0 001.64-.77c.13 2 .31 4.25.24 6.22.52 2.8-5 7.16-1.76 6.69 3.27-.23 3.51-4.28 3.51-6.8.67-1.92 1.85-3.91 1.38-6 3.89.85 4-2 7.84-4.19 1 2.7-1.35 4.62-.57 7.15 1.45 2.27.57 5.34.22 7.78.3 2 1.45 2.65 2.3.43 1.39-1.28.7-3.22.44-4.82a31 31 0 011.78-9.82 12.57 12.57 0 01-1.34 8.5c.55 2 2.44.31 3.07-.76a25.1 25.1 0 00.54-5.81 10.46 10.46 0 001.21-2.55c.71-.18 1.43-.43 2.28-.72 1.4 4 1.72 8.58-.42 12.36.55 2 2.45.32 3.07-.76a25.21 25.21 0 00.55-5.81c1.43-2.38 2.38-5.42 1.48-8.22 4.18-2 3.07-7.26 3.67-11.06 3.13-7.27-2.52-16.32-10.74-12.03zM1297.08 526.57c-8-4-1.91-15.33-23.84-14.89-18-4.66-9.65 9.93-13.11 20.46-.29 1.24-.41 3.7 1.39 3.57.63-1.1-.9-3.39.6-4.57-.15-1.82 2.1-7.26 3.89-7.78-.85.83.31 1.7.58 2.52.24 2.71-1.87 10.1 3 8.94-2.37-2.26-1.54-6.58.09-9.24 3.25 2.71 6.39 1.48 9.74 1.59.29 1.72-.3 3.3 1.19 5 .77 1.92 0 6.7 3 6.55-.16-1.05-3-12.05.24-9.38 1.61 2 0 7.39 3.44 7.4-.23-2-1.37-4.37-1.22-6.59 4.77-2.13 3 .5 6.93 1.38-.43 2.14 2.29 2.68 2.43 4.71 1.09 1 6.71 2.87 5.07-.4-1.41-3-.33-7.18-3.42-9.27zM1562.25 522.24c-1.15-2.52-.24-6.06-2.86-7.83-6.88-3.6-1.8-13-20.21-12.62-15-4.11-8.31 8.61-11.11 17.34-.25 1-.35 3.15 1.18 3 .53-.94-.76-2.89.5-3.87-.06-1.69 1.68-6 3.3-6.59-.72.7.27 1.43.49 2.12.21 2.31-1.58 8.57 2.53 7.59-2-1.92-1.31-5.58.08-7.84 4.46 4 9.37-1.66 8.25 3.71 2 1.84.45 7.1 3.54 7.41-.26-1.9-1.3-4.16-1-6.24-.33-1.73.63-3.17 1.6-1 .5 1.67.27 3.88 1.43 5.3 2.55 1.65-.52-4.08.06-5.33 3.9-1.79 2.65.42 5.88 1.17-.36 1.81 1.94 2.27 2.06 4 .93.88 5.62 2.44 4.28-.32z"/>
    
    <path class="COW_DARK_LEGS" d="M1825.67 533.58c.35 3.82.79 8.12-.83 11.72-.41.9-2.54 2.39-2.16 3.3 4.35 1.58 5.57-4.44 5.33-7.61.77-2.33 2.25-4.49 1.57-7.1-1.58-.62-2.53-1.18-3.91-.31zM1843.69 529.46a3.2 3.2 0 01-.16.39 21 21 0 01.08 5.81c0 1.73-3 4.26-.63 5.33 3.69-.87 3-5.86 3.17-8.76.24-.88 1.28-2.08 1.5-3a8.2 8.2 0 01-3.96.23z"/>
    
    <path class="COW_BODY" d="M1859.09 501.91c-2.36-5-7.18-5.13-11.67-3-5.67.34-12.38 2.12-17 5.58-3.85 3-6.24 8.24-7.87 12.69-1.7 3.25-7.76 8.75-7.86 12.43 1.57-.92 2 .2 3.29.51.81-.87 1.38-3.41 2.67-3.68 5.09 4.31-1.59 4.92 3.13 8.36 4.75-4.27 6.48 2.52 11.21-2.4 1.08-.85 2.17-3.13 3.7-3.2 1.1 3.14-1.56 5.35-.66 8.28 1.67 2.62.66 6.17.26 9 .47 2.36 1.51 3.18 2.66.5 1.6-1.48.8-3.74.51-5.58a18 18 0 011.14-7.23 8.44 8.44 0 011.09-4.68c2.41.44 4.32-.26 6.5-1 1.62 4.69 2 9.94-.49 14.32.64 2.31 2.83.37 3.56-.88a29.25 29.25 0 00.63-6.73c1.66-2.78 2.75-6.28 1.72-9.52 4.83-2.31 3.55-8.41 4.24-12.81.37-4.99 3.15-6.49-.76-10.96z"/>
    
    <path class="COW_DARK_SPOTS" d="M1824.08 535.15c-4.79-3.8.6-3.92-2.29-7.48-1.51-3.29-2.84 1.17-3.8 2.41-.48.14-1.29-.84-1.78-.89-2.84.6-3 1.82-6.22.38-2.38-1.31-2 .65-1 2.15.53 1.08 1.82 1.15 2.66 1.53-.77 3.33-3.42 3.75.51 6.72 1.13 3 .53 6.68.76 9.77.44 1.5 1.18 2.59 2.79 1.65a5.13 5.13 0 003.68-1c.7-.85.41-2.19.51-3.18 2.23-3.43 5.49-7.68 4.18-12.06z" />
    <path class="GRASS_POOL" d="M1321.2 526.64c-1.32-.11-1.38.65-.06.74s1.37-.64.06-.74zM1314.67 525.77c.07-.48-2-.64-2-.16s2 .64 2 .16zM1317.92 524.53c-1.31-.11-1.37.65-.05.74s1.37-.65.05-.74zM1309.21 526.83c-1.32-.11-1.38.64-.06.74s1.38-.65.06-.74zM1325.32 524.92c-1.31-.11-1.37.64-.06.74s1.38-.66.06-.74zM1323.72 528.88c-1.32-.11-1.38.65-.06.74s1.34-.62.06-.74zM1310.22 523.38c-1.32-.11-1.38.65-.06.74s1.38-.65.06-.74zM1321.68 522.78c.07-.47-2-.63-2-.16s2 .64 2 .16zM1329.62 526.92c-1.31-.11-1.37.65-.06.74s1.38-.66.06-.74zM1303.94 525.31c-1.31-.11-1.37.64 0 .74s1.32-.65 0-.74zM1314.35 530c-1.32-.11-1.38.65-.06.74s1.37-.64.06-.74zM1317.65 528c-1.31-.11-1.37.64-.05.74s1.4-.61.05-.74zM953.24 531.54c-1.32-.11-1.38.64-.06.73s1.37-.64.06-.73zM946.71 530.66c.07-.47-2-.64-2-.16s2 .64 2 .16zM950 529.43c-1.31-.12-1.37.64-.05.73s1.33-.64.05-.73zM941.25 531.72c-1.32-.11-1.38.65-.06.74s1.38-.64.06-.74zM957.36 529.81c-1.31-.11-1.37.65-.06.74s1.38-.64.06-.74zM955.76 533.77c-1.32-.11-1.38.65-.06.74s1.37-.65.06-.74zM942.26 528.27c-1.32-.11-1.38.65-.06.74s1.38-.64.06-.74zM953.72 527.67c.07-.47-2-.63-2-.15s2 .63 2 .15zM961.66 531.82c-1.31-.11-1.37.64-.06.73s1.4-.64.06-.73zM936 530.2c-1.31-.11-1.37.65-.05.74s1.35-.64.05-.74zM946.39 534.9c-1.32-.11-1.38.65-.06.74s1.37-.64.06-.74zM949.69 532.93c-1.31-.11-1.37.65-.05.74s1.36-.67.05-.74zM1048 533.4c-1.32-.11-1.37.65-.06.74s1.4-.64.06-.74zM1041.5 532.53c.07-.48-2-.64-2-.16s1.99.63 2 .16zM1044.75 531.29c-1.32-.11-1.37.65-.06.74s1.38-.65.06-.74zM1036 533.59c-1.31-.11-1.37.65 0 .74s1.35-.65 0-.74zM1052.14 531.68c-1.31-.11-1.37.65-.05.74s1.37-.65.05-.74zM1050.54 535.64c-1.32-.11-1.38.65-.06.74s1.37-.65.06-.74zM1037 530.14c-1.31-.11-1.37.65-.06.74s1.42-.65.06-.74zM1048.5 529.54c.07-.47-2-.63-2-.16s2 .62 2 .16zM1056.44 533.68c-1.31-.11-1.37.65 0 .74s1.32-.64 0-.74zM1030.77 532.07c-1.32-.11-1.38.64-.06.74s1.38-.65.06-.74zM1041.17 536.77c-1.32-.11-1.37.65-.06.74s1.37-.65.06-.74zM1044.48 534.8c-1.32-.11-1.38.65-.06.74s1.37-.65.06-.74zM1120.92 576.79c0 .48 2.1.31 2-.16s-2.08-.31-2 .16zM1128.42 575.47c0 .47 2.1.31 2-.16s-2.07-.31-2 .16zM1126.22 574.52c0-.48-2.1-.31-2 .16s2.07.32 2-.16zM1132.9 577c0 .47 2.1.31 2-.16s-2.07-.34-2 .16zM1118.82 574.91c0-.48-2.1-.32-2 .16s2.07.31 2-.16zM1118.4 579c0 .48 2.1.31 2-.16s-2.07-.29-2 .16zM1133.92 573.37c0-.48-2.1-.32-2 .16s2.08.31 2-.16zM1121.42 572.48c0 .48 2.1.32 2-.16s-2.07-.32-2 .16zM1112.49 577.07c0 .48 2.1.32 2-.16s-2.07-.31-2 .16zM1138.17 575.46c0 .47 2.1.31 2-.16s-2.07-.3-2 .16zM1127.77 580.16c0 .48 2.1.31 2-.16s-2.07-.32-2 .16zM1124.46 578.19c0 .47 2.1.31 2-.16s-2.07-.32-2 .16zM813 525.77c-1.31-.11-1.37.64-.06.73s1.36-.64.06-.73zM806.46 524.89c.07-.47-2-.64-2-.15s2 .63 2 .15zM809.71 523.66c-1.31-.11-1.37.64-.06.73s1.35-.64.06-.73zM801 526c-1.31-.11-1.37.65 0 .74s1.31-.69 0-.74zM817.11 524c-1.32-.11-1.38.65-.06.74s1.37-.6.06-.74zM815.5 528c-1.31-.11-1.37.65-.06.74s1.38-.65.06-.74zM802 522.5c-1.31-.11-1.37.65 0 .74s1.32-.64 0-.74zM813.46 521.9c.07-.47-2-.63-2-.15s2 .63 2 .15zM821.41 526.05c-1.32-.11-1.38.64-.06.73s1.37-.64.06-.73zM795.73 524.43c-1.32-.11-1.37.65-.06.74s1.38-.65.06-.74zM806.13 529.13c-1.31-.11-1.37.65-.06.74s1.38-.64.06-.74zM809.44 527.16c-1.32-.11-1.37.65-.06.74s1.38-.64.06-.74zM167.45 762.58c-.06.86 3.73.86 3.67 0s-3.73-.86-3.67 0zM181.14 761.25c-.06.85 3.73.85 3.67 0s-3.73-.87-3.67 0zM173.63 759.24c-.06.86 3.73.86 3.67 0s-3.73-.86-3.67 0zM189 764.58c-.06.86 3.74.86 3.68 0s-3.76-.86-3.68 0zM164 758.91c.06-.86-3.74-.86-3.68 0s3.68.86 3.68 0zM162.61 766.25c-.06.86 3.73.86 3.67 0s-3.73-.86-3.67 0zM191.32 758.24c.06-.86-3.73-.86-3.67 0s3.73.86 3.67 0zM169 754.9c-.06.86 3.74.86 3.68 0s-3.79-.9-3.68 0zM152.26 761.91c-.06.86 3.73.86 3.67 0s-3.73-.86-3.67 0zM198.67 762.58c-.07.86 3.73.86 3.67 0s-3.74-.86-3.67 0zM179.3 769.59c-.06.86 3.74.86 3.67 0s-3.73-.86-3.67 0zM173.63 765.58c-.06.86 3.73.86 3.67 0s-3.73-.86-3.67 0zM667.34 675.06c-.09.66 2.81.88 2.82.22s-2.81-.88-2.82-.22zM659.75 673.45c.1-.66-2.81-.89-2.82-.22s2.81.88 2.82.22zM662.81 672.14c-.1.65 2.81.88 2.81.22s-2.81-.89-2.81-.22zM650.72 675.32c-.09.66 2.82.88 2.82.22s-2.81-.88-2.82-.22zM673.06 672.67c-.1.66 2.81.88 2.82.22s-2.81-.89-2.82-.22zM670.84 678.16c-.1.66 2.81.88 2.81.22s-2.81-.88-2.81-.22zM652.12 670.54c-.09.65 2.81.88 2.82.22s-2.81-.89-2.82-.22zM669.46 669.31c.1-.66-2.81-.88-2.81-.22s2.81.91 2.81.22zM679 675.45c-.1.66 2.8.88 2.81.22s-2.81-.88-2.81-.22zM643.42 673.21c-.09.66 2.81.88 2.82.22s-2.81-.88-2.82-.22zM657.85 679.73c-.1.66 2.81.88 2.81.22s-2.81-.88-2.81-.22zM662.43 677c-.09.65 2.81.88 2.82.22s-2.81-.88-2.82-.22z" />
    <path class="BROWN_WOOD" d="M2132.27 451.8v-4.85h-5.34v-1.94h-4.85V447l-102.83.75v-1.94h-4.85v1.94l-102.35.74v-1.93h-4.85v1.94l-102.35.74v-1.94H1800v1.94h-4.36v4.85h4.36v3.88h-4.36v4.85h4.36v3.88h-4.36v4.85h4.36v3.88h-4.36v4.7-4.7h-5.34v-3.88h5.33v-4.85h-5.34v-3.88h5.34v-4.85h-5.33v-3.88h5.34v-4.85h-5.34v-1.94h-4.85v1.94l-102.83.75v-1.94h-4.86v1.94l-102.35.74V449h-4.85v2l-102.35.74v-1.94h-4.85v1.93H1459v4.85h4.36v3.89H1459v4.85h4.36v3.88H1459v4.85h4.36v3.88H1459v3.29-3.29h-5.34v-3.88h5.34v-4.85h-5.34v-3.88h5.34v-4.85h-5.34v-3.88h5.33v-4.85h-5.34v-1.93h-4.85v1.94l-102.83.74v-1.93h-4.85v1.94l-102.35.74v-1.94h-4.85v1.94l-102.35.74v-1.94h-4.85v1.94h-4.36v4.85h4.37v3.88h-4.36v4.85h4.36v3.88h-4.37v4.85h4.36v3.87h-4.36v4.69-4.69h-5.34v-3.87h5.34v-4.85h-5.33v-3.87h5.34v-4.85h-5.34v-3.88h5.34v-4.86h-5.34v-1.93h-4.86v1.94l-102.83.74v-1.94h-4.85v1.94l-102.34.74v-1.94h-4.85v1.93l-102.35.75v-1.51h-4.86v1.94h-4.36v4.85h4.36v3.88h-4.36v4.85h4.36v3.88h-4.36v4.86h4.36v3.87h-4.36v4.86h4.36v2.92h4.86v-2.91l102.35-.74v2.91h4.85v-2.92l102.35-.74v2.91h4.85v-2.91l102.83-.75v2.91h4.86v-2.91H1126.73v2.91h4.85v-2.91l102.34-.74v2.91h4.85v-2.91l102.35-.75v2.92h4.85v-2.91l102.83-.75v2.92h4.85v-2.91h9.7v2.91h4.85v-2.91l102.34-.74v2.92h4.86v-2.91l102.35-.74v2.91h4.85v-2.91l102.84-.74v2.91h4.85v-2.91h9.7v2.91h4.85v-2.91l102.35-.75v2.92h4.85v-2.91l102.34-.74v2.91h4.85v-2.92l102.84-.74v2.91h4.85v-2.91h5.34v-4.85h-5.33v-3.88h5.34v-4.85h-5.34v-3.88h5.34v-4.85h-5.34v-3.88zm-1122.92 8.13l102.83-.74v3.88l-102.83.74zm-107.2.78l102.35-.71v3.88l-102.35.74zm-107.2.78l102.35-.75v3.89l-102.3.74zm102.51 20.6l-102.35.74v-3.88l102.35-.74zm-102.41-8v-3.88l102.34-.74v3.88zm209.6 7.21l-102.34.74v-3.88l102.35-.74zm-102.41-8v-3.88l102.34-.74v3.88zm210.1 7.21l-102.84.74v-3.87l102.83-.75zm-102.9-8v-3.87l102.84-.75v3.88zm336.54-15l102.83-.75v3.88l-102.83.75zm-107.2.77l102.35-.74v3.88l-102.35.74zm-107.19.78l102.34-.74v3.88l-102.35.74zm102.5 20.6l-102.35.74v-3.88l102.35-.74zm-102.41-8v-3.88L1234 467v3.88zm209.61 7.21l-102.35.74v-3.88l102.35-.74zm-102.41-8v-3.88l102.34-.74v3.88zm210.12 7.22l-102.83.75v-3.88l102.83-.75zm-102.9-8v-3.88l102.83-.75v3.88zm336.54-15.05l102.84-.75v3.88l-102.83.75zm-107.19.77l102.34-.74v3.88l-102.35.74zm-107.2.78l102.34-.74v3.88l-102.34.74zm102.5 20.6l-102.35.74v-3.88l102.35-.74zm-102.41-8v-3.88l102.35-.74v3.88zm209.61 7.21l-102.35.74v-3.87l102.35-.74zm-102.41-8v-3.88l102.35-.74v3.88zm210.09 7.21l-102.83.75v-3.88l102.83-.75zm-102.89-8v-3.88l102.83-.75v3.88zm229.34-14.28l102.35-.74v3.89l-102.34.74zm-107.2.78l102.35-.74v3.88l-102.34.74zm102.5 20.6l-102.35.74v-3.87l102.34-.75zm-102.41-8v-3.88l102.35-.74v3.88zm209.58 7.29l-102.35.74v-3.88l102.35-.74zm-102.41-8v-3.88l102.35-.74v3.88zm210.09 7.21l-102.83.79v-3.88l102.83-.74zm-.06-8.73l-102.83.74v-3.88l102.83-.74zm-.06-8.73l-102.84.74v-3.88l102.83-.74z" />
    <path class="DARK_TREE" d="M1719.8 476.11c5.66-2.74 3.11-13.59-3.58-12.86-.85-8.37-9-10.63-16.12-8.34-2.95.56-2.78-2.49-3.91-4.43-4.54-6.67-20.32-3.23-19.11 5.7-7.38-2.42-14.67 7.12-9.3 13.24a1 1 0 00-1 1.41c-12.85.51-4.29 24.06 7.91 18.86-.08.56.37.68.84.59 1 2.31 5.08 1.47 6.61.21 3.61 2 10-.37 9.91-5a3.2 3.2 0 001-.25c2 2.32 6.44 2.76 8.66.53 3.87.2 7.94 2.53 9.4-3-.75-.48-2.38-2.6-.41-2.35.76-2.4 1.5 1.31 2.51 1.39 2.78 3 9-1.2 5.85-4.52a1.22 1.22 0 00.74-1.18z" />
    <path class="TRUNK_TREE" d="M1706.17 469.32c.16-.54.32-1.09.5-1.63a7 7 0 01-.77-.53c-1.62 4.53-2.38 9.35-4 13.9l-.72 2a156.24 156.24 0 01-2-21.88 1.27 1.27 0 01-1.27.43c.72 12 .2 24-.48 36-4.54-5.28-4-14.43-5.3-20.72.11 2.18-.41 5.95-.09 9.39-1.84-4.07-3.73-9.48-5-13.33 7.7 26.08 14 34.18 2 61.26h19.68c-6.34-13.53-9.84-53.85-.6-65.75-.29-.12-.58-.25-.86-.39-.33.4-.7.84-1.09 1.25z" />
    <path class="BRIGHT_TREE" d="M1737.66 453.27a3.67 3.67 0 00-.69-1 2.92 2.92 0 00-2-4.63c9.94-7.75-4.93-26.43-13-15.11 0-.82-.89-.47-1.39-.75s-.56-.87-1.12-.76c.21-2 .18-4.91-2.83-4.08 2.57-14.8-21.79-15.58-24.86-3-8.53-7.63-20.18 4.64-17.33 14-.93-.53-1.1.05-1 .72-1 .45-2.3 2.47-1 3.4-.85.18-.85 1.33-.59 2.16-14.32 3.05-3.84 25.14 8.49 18.3-.81 3 2.81 5.09 5.46 4.49 1.45-1 1.76-2.06 3.46-.75 1.85-.58 1.77-.12 3.19.87 2.6 0 5.67-2.74 5.29-5.51a1.33 1.33 0 001.46-.61c-.11 1.78 3 1.47 4 1.1 0 .33.16.56.17.84a3.87 3.87 0 001.09-.08c-1.82 7.38 11.69 8.16 13.52 1.83a.82.82 0 001.5.2c.69 2.68 6.34 1.83 5.38-.91 1.17.36 6.15 1.65 5.63-.87 6.34 2.36 13.65-5.59 7.17-9.85z" />
    
    <!-- CLOUDS -->
    <g opacity=".5" id="CLOUDS">
      <path class="cls-16" d="M333.31 7.43c-42.52-51.71-117.81-42.17-176.44-29-20.18 4.08-43.11 10.2-52.05 28.74C93.83 65.63 85.13 110.07 35.18 150c-10.95 8.78-23.26 16.35-37 19.31-40.91 8.82-80.65-24.67-122.36-21.24-72 9.27-93.72 91.88-123.61 146.78l-8.25-1.39c45.91 75.64 100.61 69 165 17.12 82.4-59.71 173.47-106.22 264.11-152.48 85.82-48.54 83.09 23.14 125-8.28 25.42-20.5 54.31-45.39 62.85-77.91-1.33-22.01-15.24-46.51-27.61-64.48zM2130.05-42c-102.79-1.63-204.05 6.8-301.27-27.92-36-1.11-71 13.32-104.2 25.84 32.11 23.91 3.31 76.77 32 101.86 49.94 11.58 63.43-61 101.16-81.78 21.64-13 48.65-11.45 73.83-9.7q99.24 6.89 198.7 9.65c20.46 1.22 20.38-17.37-.22-17.95zM1683.91 171.05a7.61 7.61 0 00-6.74 1.26 5.47 5.47 0 00-1.06-.08c2.56-7-5.41-14-12-10.79-.78-9.93-13.69-15.9-21.78-10-5.16-4.13-13.46-1.18-14.75 5.35a5.94 5.94 0 00-7.83 3.33 6.08 6.08 0 00-7.87-2.95 5.91 5.91 0 00-9.59-.22 6 6 0 00-9.78 0c-15.61-11-19.89 19.13-1.85 12.9a7.5 7.5 0 006.86 7.75c.59 6.47 8.93 10.41 14.32 6.7.23 6.09 7.35 10.61 13 8.13a7.69 7.69 0 007.24 4.29c.09 10.06 15.11 13.07 19 3.73 3.55 5.41 12.3 5.93 16.48 1.12a11 11 0 0013.3-4.71c6.89 1.14 11.33-8.22 6.2-12.85 4.3-3.84 2.48-11.52-3.15-12.96zM656.75 175.21a9.4 9.4 0 00-1.69.16c-7.85-12.79-29.45-10.33-34.21 3.88-6.5-7.1-19.45-7.3-26.16-.38 3.78-10.84-9.53-20.75-18.82-14.14-8.94-14.36-33.3-8.12-34 9a18.69 18.69 0 00-12.79 5.17c-.27-.3-.54-.58-.83-.86 5.14-11.3-11-21.07-18.65-11.46-4.82-11-21.57-13.44-29.33-4.18-10.25-12-31.85-3.81-31.22 12.24a19.27 19.27 0 00-20.57 19.22c-.67 19.16 26.77 26.39 35.81 9.9 3.79 10.07 18.85 12.63 25.75 4.29a9.87 9.87 0 009.05-2.81 13.08 13.08 0 0016.44-.38 15.54 15.54 0 0010.59-2.46c5.42 9.58 20.46 11.77 28.39 4 2.47 5 10 6.44 14.16 2.69 2.86 6.76 13.22 8.08 17.68 2.2 3.91 3.47 10.87 2.67 13.9-1.53a18.88 18.88 0 0019.43-3c1.68 10.07 17.29 10.14 19 .09 8.12 8.38 23.1-.72 19.23-11.87 12.03-1.26 10.96-19.98-1.16-19.77zM1580.33-4.34a9.15 9.15 0 00-8-8c-3.06-7.35-13.91-9.41-19.45-3.55-1.52-13-21.19-14.21-24.45-1.74-7.35-5.79-19.16.49-18.36 9.88a11 11 0 00-11.49 3.4c-4.36-5.06-13.69-3.12-15.67 3.25-13 .59-5.32 20 4.57 11.62a9.5 9.5 0 0010.55-1.38c3.34 5.06 11.49 6.11 16 1.91 4.19 5.88 14.18 6.15 18.66.38 5.06 7.19 17.55 6 21.16-2 4.51 3.85 12.43 1.54 14.19-4.07 6.24 2.44 13.27-3.08 12.29-9.7z"/>
    </g>
    <!-- end - CLOUDS -->
    
    ${
      !darkMode &&
      `
    <!-- SUN -->
    <path id="SUN" d="M1913.32 236.58c-1.33-56.05-78.36-52.85-80.18 0 1.86 52.85 78.86 56.04 80.18 0zM1916.18 164c-3 1.49-26.8 20.7-22.8 23.16 2.08 3.52 15.6-13.46 19.68-15.35 3.11.46 8.36-7.15 3.12-7.81zM1945.29 199.44c2-1 4.37-1.05 6.16-2.22 1.83-1.78.15-4.93-2.29-4.72-3.94 2.06-27.29 7.62-25.17 11.74 1.68 5.31 16.89-4.24 21.3-4.8zM1973.12 228.89c-9.51-1.56-20.08 1.87-29.94 1.63-3.56-1.82-5.31 4.67 2.25 3.27 7.52-.5 15-1 22.58-1.12 2.48.25 7.63-.18 5.11-3.78zM1958 271.14c-3.72-3.43-9.21-4.57-13.64-7-3.08-1.36-10.56-6.21-10.18.47 3.74 4.46 11.1 5.44 16.14 8.51 2.84 1.88 9.44 3.88 7.68-1.98zM1914.37 302.18c-2.67-4-5.67-7.76-7.57-12.22-1.55-2.31-1.47-7.85-5.14-7.39-5.47 2.58 7.85 20.82 10.22 24.56 3.4 1.54 4.39-2.76 2.49-4.95zM1880.78 323.58c-1-8.13-2.43-16.42-2-24.63 2.92-2.5-3.38-5.07-2.78 1.06.27 8.63.14 17.6 1.68 26.07 1.64 2.38 4.5-.24 3.1-2.5zM1848.45 292.86c-4.33-.44-14.45 18.79-17.27 23.1-.59 4.08 5.36 2.33 4.62-.86a185.89 185.89 0 0110.53-17.65c1.2.78 3.54-4.02 2.12-4.59zM1830.82 277.09c-2.78-5.88-26.46 18.12-31 21-2.17 2 .65 5.7 3.17 4.11 2.66-2.4 7.39-3.66 8.66-7.09 3.22-4.23 21.49-13.76 19.17-18.02zM1805.33 252.82a30.05 30.05 0 019.53.47 2.22 2.22 0 00.53-4c-7.68-2.68-16.27.21-24.15.84-3 .78-12-.07-8.84 5.14 3.38 1.46 8.59.07 12-1.07 3.6-.58 7.27-1.07 10.93-1.38zM1782.11 217.74c11.34 3.08 23 5.26 34 9.75 13.67-4.24-26.61-12.3-29.83-13.35-1.83-4.14-8.6 1-4.17 3.6zM1791.81 181.79c2 3.1 40.65 29.16 39.19 20.36-9.25-6.54-21.37-9.94-30-17.94-3.54-2.21-6.09-6.37-9.65-8.09-3.71.48-1.6 4.42.46 5.67zM1830.08 164.6c6.09 6.62 10.47 16.23 17.71 21.21 8.58-1.26-10.12-17.52-11.57-21.67 1.17-5.81-10.04-6.76-6.14.46zM1871 171.5c-.2 3.05 1.38 11.35 5.06 6a124.56 124.56 0 01-.08-29.33c2.21-2-.28-7.06-3.27-5-3.71 8.22-1.85 19.24-1.71 28.33z"/>
    <!-- end - SUN -->
    `
    }

    ${
      darkMode &&
      `<!-- moon-and-stars -->
    <g id="MOON" transform="matrix(1, 0, 0, 1, 1703.076538, 87.224792)">
      <path class="st0" d="M139.7,200.3c53.9-14.6,54.5-93.5,0.4-108.6c48-16,91.1,47.9,58,88.5C184.6,198,156.4,207.8,139.7,200.3z" style="fill: #c5daef;"/>
      
      <g id="STARS_RIGHT" class="st1" opacity="0.3">
        <path class="st0" d="M385.3,153.1c1.5,1.3,3.1,2.8,4.8,4.3c-1.3,1.4-2.8,3-4.3,4.6c-1.5-1.3-3.1-2.7-4.8-4.1 C382.4,156.4,383.9,154.7,385.3,153.1z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M262.9,68.3c-1.3,1.4-2.7,2.9-3.9,4.3c-1.4-1.2-2.9-2.6-4.3-3.8c1.3-1.4,2.6-2.9,3.9-4.4 C260.1,65.7,261.5,67,262.9,68.3z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M228.6,243.2c-1.2-1.1-2.4-2.2-3.7-3.4c1-1.2,2.1-2.5,3.3-3.8c1.2,1,2.5,2.1,3.8,3.3 C231,240.5,229.9,241.8,228.6,243.2z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M350.9,62.5c-1-0.8-1.9-1.7-3-2.6c0.8-1,1.7-2,2.6-3.1c1,0.9,2,1.8,3.1,2.7C352.7,60.5,351.8,61.5,350.9,62.5 z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M263.4,153.3c0.9-1,1.7-2,2.7-3c1,0.9,2.1,1.8,3.2,2.7c-0.9,1-1.8,2-2.8,3 C265.5,155.1,264.5,154.2,263.4,153.3z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M312.6,115.8c1,1,2,1.9,2.9,2.7c-0.9,1-1.7,2-2.6,3c-1-0.9-1.9-1.8-3-2.7 C310.7,117.9,311.6,116.9,312.6,115.8z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M292.4,211.4c1.1,1,2,1.9,3,2.8c-0.9,1-1.7,1.9-2.7,3c-0.9-0.8-1.9-1.7-2.9-2.7 C290.6,213.5,291.5,212.5,292.4,211.4z" style="fill: rgb(255, 255, 255);"/>
      </g>

      <g id="STARS_LEFT" class="st1" opacity="0.3">
        <path class="st0" d="M75.7,171.9c1.2,1.1,2.5,2.2,3.8,3.4c-1.1,1.1-2.2,2.4-3.4,3.7c-1.2-1-2.5-2.1-3.8-3.3 C73.3,174.4,74.5,173.1,75.7,171.9z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M101.6,61.6c-1,1.1-2.1,2.3-3.1,3.4c-1.1-1-2.3-2-3.4-3c1-1.1,2.1-2.3,3.1-3.5 C99.3,59.5,100.5,60.6,101.6,61.6z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M232.2,15.2c-1-0.9-1.9-1.8-2.9-2.7c0.8-0.9,1.7-2,2.6-3c0.9,0.8,1.9,1.7,3,2.6 C234.1,13.1,233.2,14.1,232.2,15.2z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M123.3,4.5c-0.8-0.7-1.5-1.3-2.4-2.1c0.7-0.8,1.3-1.6,2.1-2.5c0.8,0.7,1.6,1.4,2.5,2.1 C124.8,2.9,124.1,3.7,123.3,4.5z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M31.3,89.5c0.7-0.8,1.4-1.6,2.1-2.4c0.8,0.7,1.6,1.4,2.5,2.1c-0.7,0.8-1.4,1.6-2.2,2.4 C32.9,90.9,32.1,90.2,31.3,89.5z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M119.5,143.8c0.8,0.8,1.6,1.5,2.3,2.2c-0.7,0.8-1.4,1.6-2.1,2.4c-0.8-0.7-1.5-1.4-2.4-2.1 C118.1,145.5,118.8,144.7,119.5,143.8z" style="fill: rgb(255, 255, 255);"/>
        <path class="st0" d="M2,40.3c0.9,0.8,1.6,1.5,2.4,2.2c-0.7,0.8-1.4,1.5-2.1,2.4c-0.7-0.7-1.5-1.3-2.3-2.1 C0.7,41.9,1.3,41.1,2,40.3z" style="fill: rgb(255, 255, 255);"/>
      </g>
    </g>
    <!-- END - moon-and-stars -->`
    }


    <path class="GRASS_POOL" d="M660.31 590.32c9.3 2.92-2.94 7.07-6.82 8.82-6.84.51-13.31 2.23-20.82 1.45-3.69 1.37.57.24 1.73 1.9 1 2.38-1.75 5.38-4.34 5a50.27 50.27 0 01-28.54 4.68c-1.59 1.46-2.32 1.86-4.16.41-1.63 1.11-2.59 1.09-4.18-.08-4.85 1.61-11.69.33-16.55-1.41-3.79 2.29-5.18-2.75-8.49-1.3-3.52-3.05 4.46-5.49-.54-5.19-30.09 1-30.78-11.32.59-13-2.81-.85-.72-2.75-2.71-3.31-1.72 1.21-2.73.92-4.24-.38-3.4.84-8.28 1.66-10.5-1-21.18-5.25 25.26-10.35 29.46-8.74 1.64 1.06 2.59.7 4.1-.2 1.73 2.08 3.88 1.37 6.14.79.68 2.47 6.6 2.36 4.46 4.91 7.59.47 15.83-.34 21.88 4.27 2.63-.29 4.32 1.83 6.18-.89 2.81 1.72 2.21 1 3-1.63 4.11-3.49 9-1.33 13.51-4.52 10.4-.73 61.53.97 20.84 9.42zM1212.55 522.12c-14.89 7-38.07 5.85-52-2.2 7.29-7.33 43.33-5.35 52 2.2zM1211 746.16c-12.37-6-24.74-7.51-38.31-8.34-3.13-.36-34.55.42-23.66 6.56-4.69 2.51-19.3-2.59-26.56 3.67-30.32 4.84 1.6 11.16 13.13 12.65 9.63 2.58 17.28-.32 27.21 2.12 7.4-7.59 22.57.85 29.61-7.12 4.42-3 7.08-6.23 13.29-3.63 3.02.04 10.78-3.69 5.29-5.91zM1437.31 526.15c2.41-7.43 51.48-9.93 47.65-.3 9 .14 30.08 4.36 10.51 9-16.55 1.56.17 4.72 7.43 4.78-.05 9.73-31.92 7.78-36.37 3.28-1.16-3.57-28.14.53-10.24-8.09 3.85.3-2.44-.85-1.83-2.39.03-3.51-14.84-.98-17.15-6.28zM962.64 773c-7.65 6.7-9.59 3.67-18.3 3.89-10.54 2.16-20.49 1-29.36-.33-9 1.74-13.39-3.18-21.56-4.68-8.63-2.81-18.92-1.24-23.92-10.06 2.32-6.78 11.12-.29 14.45-6.24 9.67 1.8 18.95.62 29.71.84 16.1 6.12 35.61 3.14 48.98 16.58zM163.34 606.6c-1-10.94-30.37-11.45-40.09-12.66-3.75-4.42-8-1.28-12.63-1.63-4.47-4.1-10.21-.49-15.93-2.45-3.22 3-29.3 2.06-17 9.58-6.26.48-21.42 1.27-27.49 1.07-8.58 2.37-12.19 7-1.13 9.68 2.33 4.42 15.12 6.38 20.87 5.77 3.76 2.18-1.87 3 1.65 5.2a10.12 10.12 0 00-5.5-1.36c-6.63 3-15.69 1.66-22.58 1.93-3.7 6.11 7 11.66 12.22 9.93 3.93 3.39 11 4.37 15.73 3.36 3.26 1.46 6.32-.55 9.69.2 2.5 2.49 3.45 3.12 6.4.74 5.93 4.42 13.29-2.36 19.47-.4 2.59-3.94 1.09-6 7.28-5.36 6.36 1.82 15.21 1.11 22.21-.22 2.55-3 2.13-7.48-2.81-6.72-2.82-1.28-4.92-4.49-8.31-3.37 2.73-2.71 9.85-2.57 5-8.41 10 3.84 26.11 1 32.95-4.88zM336.71 681c-7.66 6.7-9.6 3.68-18.31 3.89-10.54 2.16-20.49 1-29.36-.33-9 1.75-13.39-3.17-21.55-4.68-8.64-2.81-18.93-1.24-23.93-10.06 2.32-6.78 11.13-.28 14.45-6.23 9.67 1.79 18.95.61 29.71.84 16.1 6.16 35.61 3.18 48.99 16.57z" />
    
    <path class="GRASS_DARKER" d="M846.33 592.29c-7.42 3.17 13.18-18.21 4.37-13.38-7.72 5.67-10.31-1.83-5.58-8.14-1.63-2.16-4.61 5.26-5.2 1.12-2.2-7.56-1.9 1-.94 4.08-2.8 3.14-8.78 14.78-2 14.56 7.78-9.22-2.66 9.86-5.16-4.44-2.32-9.55-.66-18.6.33-28.1-8.53 9.79-3.21 34.81-16.3 10.52-2.42 4.55 8.71 19 .73 20.47 2.61 1.23-2.34 8.23-.48 4-.44-8.28-4.19-16.17-7-23.73-4.1 9.3 10.65 21.4-8.14 9.63 6.55 8.32 9.05 17.58 7.79 27 8.55-4.3 2.38-8.52 8.49.29 5.34-5 1.85-15.3 8.52-6.08-4.91 8 5.68 5.33 7.46.68 3.83 3.4 2.79-7.24 5.5-8.9 1.45-.24-3.8 24.52 5.63 6.76 3.34 18.16 9.2-12 10.61-18.08-.67-3.43-6.83 9.24-8.63 11.74zm-21.59-9.4a11.33 11.33 0 01.32-1.71c-.17.65.34 3.32-.32 1.71zm4.26 11.64c-3.19-1.91-3.73-2.8-2.89-6.52.43 1.58 5.08 8.76 2.89 6.52zM855.14 605.09c7.24-1 12.29-10.31 13.9-16-4.5 3.98-17.37 8.64-13.9 16z" />
    <path class="GRASS_DARKER" d="M795.43 582c6.59 14.66 4.26 12.93-8.34 7.08.65 3 13 19.91 13.38 9.42.51-1.08 7.32 11.34 5.52-4.37-2.99-3.45-5.9-12.53-10.56-12.13zM717.78 817.11c-3.65-7.13 19-21.63 1-13.43-5.67 3-2.71-8.15-1.52-10.54-3.93 2.6-4.91 3.87-5.89-1.63-2.2 1.88 1.68 8-1.93 10.63-5.38 4.63-2.82 18.16 3.06 7.24-5.67 15.18-10.06-5.82-9.85-13.19v.11c-.46-4.58 3.68-12.17 1.32-15.43-2.67 6.67-6.22 15.45-6.77 21.8-2.47 2.45-6.14-9-8.9-11.26-2.45 4 8.52 20.08 1.12 20-.41.51-.53.38.08 1.16 1.57 1.5-1.1 3.45-1.57 5.16 1.84-8.39-3.86-17.65-6.41-25.59-2.36 3.25 1.79 10.84 1.32 15.42a.59.59 0 010-.11c-12.55-9-10.13-6.39-2.85 5.24h-.05c3.31 4 .64 11.49.76 16.11 3.28.12 5.18-3.87 6.23-6.61a12 12 0 002.11 6.93c3.29-1.67 4.51-7.46 5-11.15 3.62 3.6 3.55 5.9 3.23 10.38a9.11 9.11 0 008.32-4.35c4 2.7 3.14-8.13 6.34-10.48-1.36 7.67-3 23.65 4.91 8.06 2.93 20.13 9.28-12.88 10.61-18-.24-4.26-8.2 11.2-9.67 13.53zm-20.55-11.67c.13-.53.23-1 .31-1.37a17.44 17.44 0 000 2.4c-.09-.35-.46-.65-.31-1.03zm1.12 7.78a11.39 11.39 0 00.22-2.34c.76 2.92 3.32 4.69 3.59 7.64-.78-2.61-5.33-2.29-3.81-5.3zM735.38 823.3c1.61-3.59 6.34-7.94 6.13-11.33-13.03 5.31-22.41 24.87-6.13 11.33zM735.41 823.28zM735.37 823.32s0-.02 0 0z" />
    <path class="GRASS_DARKER" d="M667.9 804.92c2.92 3.88 3 9.63 4.41 14.21-.95-2.5-13.6-8.86-12.66-6 2.69 3.33 14.53 20.18 13 6.84 4.1 8.6 7.84 4.45 5.82-3-3-3.38-5.91-12.47-10.57-12.05zM523.64 655.93c5.94-9.39 7.69-11.47-2.32-4.27v.09c-.38-3.73 3-9.93 1.08-12.58-2.08 6.47-6.73 14-5.23 20.87-1.7-3.08-1.76-2.41-1.21-5.16-5.47 0 1.7-12.07 1.39-16.1-2.85.27-5.46 11.38-7.73 9-.45-5.18-3.34-12.33-5.52-17.77-1.92 2.67 1.45 8.84 1.08 12.58v-.09c.18 6-3.4 23.12-8 10.75 4.79 8.9 6.88-2.13 2.49-5.9-2.94-2.11.23-7.14-1.57-8.66-.8 4.52-1.6 3.4-4.8 1.32 1 1.94 3.38 11-1.24 8.59-14.68-6.68 3.79 5.13.82 10.95-1.12-2-9-16.52-7.59-10 1.12 4.47 6 29.2 8.41 13.6 6.3 12.6 5.17-.32 4-6.57 2.61 1.92 1.87 10.75 5.17 8.55a7.45 7.45 0 006.78 3.55c-.26-3.66-.31-5.54 2.63-8.47.36 3 1.35 7.73 4 9.09a9.75 9.75 0 001.73-5.65c.6 1.9 3.27 6.79 5.25 4.91-.62-3.58-1.92-9.61.44-12.65zm-18.08 4.75c.22-2.4 2.31-3.84 2.93-6.22a10.41 10.41 0 00.56 3.4c-1.25.77-2.86 1.38-3.49 2.82zm3.75-9.81a16 16 0 000-2c.07.36.2.88.3 1.34-.09.25-.2.45-.3.66zM473.49 655.35c-.17 2.76 3.69 6.31 5 9.24 14.03 11.3 4.41-5.81-5-9.24zM478.46 664.56s.01.02 0 0zM478.5 664.6z" />
    <path class="GRASS_DARKER" d="M529.89 661.18c4.54-16 3.67-14.74-5-1.69-1.75 6 1.56 9.29 4.73 2.41-1 10.61 8.75-3.12 11-6.13-2.53-.29-8.84 2.76-10.73 5.41zM1077.87 672c-3.23-6.32 16.86-19.18.9-11.91-4.15 2.77-3.65-6.87-1.06-8.87-3.32-.6-4.14 5.39-5.51-1.9-2 1.65 1.49 7.12-1.71 9.41-4.77 4.11-2.5 16.1 2.72 6.42-5 13.45-8.92-5.16-8.73-11.69v.1c-.4-4.07 3.27-10.79 1.18-13.67-2.37 5.91-5.52 13.69-6 19.31-2.19 2.18-5.45-8-7.89-10-2.17 3.58 7.55 17.78 1 17.71.63 3.19.56 2.05-1.33 5.6 1.64-7.43-3.42-15.65-5.67-22.68-2.1 2.88 1.58 9.6 1.16 13.67v-.1c-10.9-7.85-9-5.54-2.52 4.64-.09-.1 0 0-.05 0 2.58 3.3 1.16 9.87.49 13.75 2.16 2 5-3.28 5.71-5.34.73 11.61 6.08 2.4 6.26-3.73 3.2 3.18 3.14 5.22 2.86 9.2A8.12 8.12 0 001067 678c3.58 2.39 2.78-7.2 5.62-9.29-1.28 6.82-2.5 20.82 4.35 7.14 2.71 17.21 8.2-11.09 9.4-16-.14-3.64-7.19 10.06-8.5 12.15zm-18.2-10.34c.11-.47.2-.88.27-1.22a16.79 16.79 0 000 2.13c-.09-.33-.41-.57-.27-.93zm1 6.89a10.19 10.19 0 00.19-2.08c.68 2.59 2.94 4.16 3.19 6.77-.71-2.33-4.73-2.04-3.39-4.71zM1093.47 677.46c1.42-3.18 5.62-7 5.43-10-10.83 4.13-20.31 22.17-5.43 10zM1093.5 677.44v.05z" />
    <path class="GRASS_DARKER" d="M1037.58 673.76c-.85-2.21-12-7.85-11.22-5.27 2.49 3.23 12.59 17.39 11.53 6.06 3.63 7.62 6.94 3.94 5.15-2.63-9.56-14.29-10.38-15.64-5.46 1.84zM1554.27 683.05c-3.19-3.12 6.09-10 6.9-13.89-6.91 4.6-13 2.15-7.38-6.28-.39-.6-.16-.53-1.17-.08-4 4.16-2.7.15-4.89-1.81 3 7.34-7.58 13.45-2.13 20 2.39-.74 4.46-7.22 3.22-1.07-14.27 9.75-3-39.24-8.85-23.53-3.4 2.78-2.9 17.55-5.74 14.53-1.41-2-7.8-14-6.44-7.56 2.86 9.59 4.25 13.73 0 20.25.27-7.26-3.09-16.47-6.54-22.07-.68 9.63 7.17 18.46-6.26 8.14 2.82 7.27 9.77 14.69 5.88 23.77 6.53 1.46 3.7-10.27 7.59.8 4.3-5.09 6.62-14.76 7-1.73 1.81 4.34 7.18-3.82 8.89-2.1 1.61-1.85 4.61-14 3.81-7.18-1.09 12.1-.28 12.08 4.91 5.42 3.72 14 7.92-12.26 9.36-17.08-.77-2.88-6.43 8.99-8.16 11.47zm-18.52-9.73c.11-.47.19-.88.27-1.22-.02.9.08 3.11-.27 1.22zm1 6.89c-.35-4.34 2.89 2.87 3.38 4.69-.71-2.31-4.74-2.02-3.39-4.69zM1562.67 693.3c6.43-.9 10.87-9.11 12.31-14.2-3.98 3.55-15.39 7.68-12.31 14.2z" />
    <path class="GRASS_DARKER" d="M1509.75 672.86c5.85 13 3.78 11.45-7.38 6.27.58 2.69 11.54 17.65 11.85 8.35.46-1 6.48 10 4.9-3.88-2.66-3.07-5.23-11.12-9.37-10.74zM1372.32 659.29c6.72-10.21-1.91-2.07-5.32-.2 5.38-24.28-5.19-3.5-4.82 8.41-6.31-9.21 0-12.42 0-22.69-11.62 21.6-6.87-.71-14.44-9.32 1.77 5.37 2.48 36.9-5 28.26 2 1.8 3.74-.61 3.26-4.34-1.36-4.68-5.7-7.66-3.71-13-1.5-4.45.45 6.37-5.83-.08 4.22 8.53.32 11.64-7.68 6.75 9.5 12.65 8.89 17.54-1 1.15-.57 2.94 5.68 32.33 8.91 19.33 7.18 5.52 5.86 5.29 4.54-9.22 2.72 1.73 2.07 11.86 5.51 9.07 11.66 13.87 6.26-11.1 10.72-2.28 7.15 17.1 1-4 11 6.81.48-5.65-1.74-13.55 3.86-18.65zm-21.4 6.75c2.19-3.4 2.29-4.58 2.48-.13-2.5 1.09-4.77 4.46-2.48.09zm3.06-10a9 9 0 01.28 1.51c-.58 1.45-.13-.92-.26-1.55zM1314.61 663.4c.83 4.16 14.59 21.5 12.81 9.78-2.65-3.96-8.85-8.56-12.81-9.78z" />
    <path class="GRASS_DARKER" d="M1377.35 665.13c1.1-5.86 5-13.47-2.38-4-5.61 5-6.42 20.36.91 9.54-.77 10.69 11.18-4.57 11.74-7.59-4.26-.08-14.06 10.02-10.27 2.05zM347.47 714zM372.29 716.9c-2.4-4.67 12.47-14.18.66-8.8-3.72 1.93-1.78-5.35-1-6.91-2 .74-2.91 3.42-3.6-.05-1.58-3.49.32 4.12-.81 4.8-3.72 2.94-3.41 13.57 1.29 5.89-3.45 9.57-6.76-3.68-6.45-8.64v.07c-.29-3 2.42-8 .87-10.12-1.75 4.38-4.08 10.13-4.44 14.29-1.82 1.93-3.92-7-6.22-7.23-.25 3.24 5.53 12.95 1.13 13 .41 1.93.32 2-1 4.14 1.2-5.5-2.53-11.57-4.2-16.78-1.56 2.13 1.17 7.11.86 10.12v-.08c-7.89-5.71-6.61-4-1.87 3.44 1.91 2.45.86 7.31.36 10.18 1.59 1.51 3.74-2.42 4.22-3.95a7.86 7.86 0 001.39 4.54c2.16-1.09 2.95-4.89 3.25-7.3 4.39 3.32-.87 11.52 7.58 3.92 2.75 1.62 2-5.28 4.16-6.86-1 5.07-1.7 15.25 3.22 5.28 2 12.74 6.07-8.2 7-11.83-.51-2.47-5.26 7.15-6.4 8.88zm-13.47-7.65c.08-.35.15-.65.19-.9a13.65 13.65 0 000 1.57c-.01-.22-.29-.42-.19-.67zm.73 5.1a7.12 7.12 0 00.14-1.54c.5 1.92 2.18 3.08 2.36 5-.51-1.7-3.5-1.49-2.5-3.46zM383.82 721c1.06-2.35 4.17-5.21 4-7.43-6.88 2.23-15.67 16.62-4 7.43z" />
    <path class="GRASS_DARKER" d="M383.85 720.94c.03-.04-.01.06 0 0zM342.48 718.22c-1.52-2.13-6.59-4.58-8.62-4.35 1.8 2.42 9.61 13.46 8.84 4.93 2.56 5.54 5.21 2.88 3.81-1.94-6.81-10.35-7.66-11.36-4.03 1.36z" />
    
    <path class="COW_DARK_LEGS" d="M329.38 640.41c-2.1 6.76 1.86 13.12 4 19.24 0 6.34.42 13.62 5 18.58 2.15 1.38 6.78 3.07 9 1.32 1-2.37-4.58-6.27-5.64-8.62-3.07-6.52-3.48-14.86-2.65-21.9-.54-3.85.84-8.61.66-12.27-5.51-7.62-8.89-4.09-10.37 3.65zM295.55 619.42s-1.34-14.84-14.61-7.87c-.15.08.11 1.55 0 2-2.91 17.76 6.49 17.28 5 30.19.52 3.24.85 7.47 1.66 10.61 1.89 3.24 7.61 8.38 9.29 2.32-6.74-13.07-5.52-23.66-1.28-37.44"/>
    <path class="COW_BODY" d="M252.08 557.48c7.39-13.71 17.47-13.27 30.52-8 14.83.89 32.36 5.53 44.45 14.59 10.07 7.91 16.3 21.51 20.57 33.17 4.46 8.53 20.3 22.9 20.57 32.51.19 6.77-12.23 20.65-23.22 13.94-2.09-1.28-6.19-4.36-8.63-4.65-3.23-.38-9.38 3.8-12.6 3.32-8.16-1.68-12.17-12.32-18.31-13.68-2.84 10.06 4.24 13.32 1.72 21.64-4.37 6.88-1.72 16.15-.66 23.55-1.41 6.28-3.76 8.49-7 1.33-4.2-3.88-2.1-9.77-1.33-14.6.72-6.19-1.12-13.09-3-18.9a22 22 0 00-2.87-12.22c-6.46 1.07-10.59-.48-17-2.67-4.24 13.8-5.45 24.37 1.28 37.44-1.68 6-7.4 1-9.29-2.32-1.44-5.52-1.58-11.92-1.66-17.58-4.35-7.26-7.18-16.43-4.49-24.88-2.23-1.55-6.4-4.61-7.78-7-2.79-7.77-2.21-18.37-3.32-26.53-.87-15.52-8.73-14.35 2.05-28.46z"/>
    <path class="COW_DARK_SPOTS_2" d="M349.28 636.43c0-1.68-2.33-4.63-2.32-6.3.53-2.46 3.41-7.62 5.64-8.63 3.37.72 4.85 7.34 7 9.62 1.24.38 3.36-2.18 4.65-2.32 2.85-.1 5.71 2.25 8.29 3 3.72.34 8.88-3.41 12.27-3 1.37 2.92-2.12 8.15-5 9.62-.83.45-3.24.14-3.65 1-.16 3.36 4.68 7.51 4.31 11.28-.75 2.65-4 4.33-5.64 6.31-4.3 8.24 1.59 26-5.3 30.85-.95.38-3-.87-4-1-3.12.34-7.24-.51-9.62-2.65-3.22-5.93 1.32-7.13-5-13.6-4.77-7.37-10.15-17.24-7.3-26.21 1.67-2.53 5.96-4.35 5.67-7.97zM338.1 612.34c-1.25 2.49-16.85 12.25-14 12.52 6-.34 12.07-8.22 16.95-11.9.29-1-2.42-1.21-3-.62zM333.49 607.34c-3.52 5.55-11 11.64-14.25 15.34 2.76-.29 22.76-21.68 14.25-15.34zM290.37 550.52c-10.79-2.5-18.7 20.34-13 27.62.66 2-.88 4-1.14 6 0 8.54 11 7.66 16.78 5.25 1.78-.68 3.42-.14 4.07 1.64 6.33 7.11 16.78-8.18 27-5.65 28.08 4.5 6.6-25.35-7.15-27.78-.03.01-18.16-8.34-26.56-7.08zM253.68 557.14c4.59 5.39 6.33 19.7-2.36 21.48-8.74-3-6-17.51.32-21.74"/>
    
    ${
      !darkMode &&
      `<!-- sunglasses-white-left -->
      <path class="COW_BODY" d="M356.59 658.08c-1.4-3.26-.13-7.57 4.1-7.06-8.59-1.32-7.67 10.56.39 9.42-1.74-.2-3.76-.63-4.49-2.36zm18.66-.26c-2.73-4.84 0-6.38 4.66-6.8h-.76a11.33 11.33 0 00-6 1.77c-1.32 3.46 1.84 8 5.66 7.69h.67a5.44 5.44 0 01-4.23-2.66z"/>
    <path id="sunglasses-white-left" class="COW_BODY" d="M387.14 652.12v-2.35l-6.4-.34c-7.61.18-6.15 1.81-11.08 1.92-4.92-.1-3.5-1.75-11.07-1.92l-6.4.34v2.44c1.62.75.89 5.93 2.44 7.44 3.07 2.7 12.22 4.05 13.83-5.08a1.29 1.29 0 012.46 0c1.5 9.08 10.81 7.81 13.82 5.09 1.56-1.65.8-6.35 2.35-7.42h.09z">
    </path>
    <!-- END - sunglasses-white-left -->

    <!-- START - sunglasses-white-shine-left -->
    <path id="sunglasses-white-shine-left" d="M360.43 660.46c-7.54.51-8.05-10.74.26-9.44-6.65-.7-5.84 9.93.39 9.42zM378.85 660.46c-3.82.28-7-4.23-5.67-7.69a11.39 11.39 0 016-1.77h.76a11.25 11.25 0 00-5.41 1.75c-1.24 3.2 1.5 7.54 5 7.67z" style="">
    </path>
    <!-- END - sunglasses-white-shine-left -->
    `
    }

    <path class="OWL" d="M253.44 534a44.36 44.36 0 01-4.12 10.72c.42-.24.72-.62 1.13-.82a20.71 20.71 0 01-2 4.94c6.06.9 8.47-4.6 13.59-6.5a4.23 4.23 0 002.27 2.84c.41.1.28.63.56.91a2.15 2.15 0 00-1.61.16.88.88 0 00-1.12.85c.36-.51 1-.68 1.41-.13.29.25.51-.18.77 0 .45 0 .86.18 1.33.17a3.43 3.43 0 01.31.6c-.63-.26-1.15.09-1.73.19-.47-.37-1.43.65-1 .83.32-.76 1.13-.34 1.55 0 .2.1.4-.26.55-.17a6.8 6.8 0 011.31.23c.88.17 1.68-.2 2.56-.07l.09-.16c.13 0 .27.11.38-.07s.38.2.56 0a10.13 10.13 0 001.46 0 1.26 1.26 0 01.8.24c.28.08.69-.33.48-.63.65 0 1.48.18 1.69.89.45-2.39-5.14-.7-5.69-2.21.47.22 1-.11 1.42.05s1.09.47 1.07-.4c1-.05 1.27.6 1.64.76-.45-2.07-3.93-.87-5.23-1.64-.93-9.31 10.6-10.2 8.81-22.28a22.67 22.67 0 00-1.4-5.47A11.39 11.39 0 00276 511c-.78-4.8-8-5.2-11.15-2.56-2.48 2.75-1.87 6.57-2.3 10-.12 2.7-3.05 3.31-4.33 5.29-2.46 2.91-3.53 6.71-4.78 10.27zm10.91-21.52c-.31-3 2.79-5.29 5.36-3.45a4.44 4.44 0 013.36-.46c2.78 1.08 2.53 4.89 1.46 7.15-2.65 4.98-10.89 2.41-10.18-3.25zm-3 23.13h.05c4.79-3.91 8.85-13.24-.74-13.27a6.28 6.28 0 002.12-1.56 5.94 5.94 0 015.21 2.76c3.13 5.65-4.69 10-7.08 14.42a5.2 5.2 0 010-1.67 25 25 0 00-6.38 5.87l.07-.82a10.63 10.63 0 01-3.74 2.2 12.11 12.11 0 004.1-4.45 10.65 10.65 0 00-.08 1.36 46.23 46.23 0 016.7-6.25c-.07.48-.13.92-.19 1.4z"/>
    <path class="COW_BODY" d="M264.35 512.47c-.71 5.66 7.53 8.23 10.14 3.24 1.07-2.26 1.32-6.07-1.46-7.15a4.4 4.4 0 00-3.36.46c-2.57-1.84-5.68.47-5.36 3.45zm5.5 4.95c-.4-.21-.39-1.09-.65-1.53a4.76 4.76 0 01-1.39-2.65c-.67 0-1.38-.44-1.08-1.17-.26 0-.66.24-.83 0 3.48-1.44 2.11 1.06 3.13 3.17.39.35.34-.88.84-.62.85 1.51.93-.22 1.1-1.08.07-2.48.9-2 2.71-1.48v.05c-.27.23-.57 0-.86 0 .28.73-.41 1.29-1.12 1.14.03 1.6-1.76 2.49-1.85 4.17zM261.39 535.6c.06-.48.12-.92.17-1.4a46.23 46.23 0 00-6.7 6.25 10.65 10.65 0 01.08-1.36 12.11 12.11 0 01-4.1 4.45 10.4 10.4 0 003.74-2.2l-.07.82a25 25 0 016.38-5.87 5.2 5.2 0 000 1.67c2.39-4.42 10.21-8.77 7.08-14.42a5.94 5.94 0 00-5.21-2.76 6.15 6.15 0 01-2.12 1.56c9.6 0 5.52 9.36.74 13.27z"/>
    <path class="OWL" d="M269.85 517.42c.09-1.68 1.88-2.57 1.85-4.2.71.15 1.4-.41 1.12-1.14.29 0 .59.22.86 0V512c-3.51-1.41-2.14 1-3.17 3.16-.38.34-.35-.83-.85-.6-.84 1.68-1.1-.65-1.06-1.46-.32-2.23-1.15-1.44-2.7-1.09.17.28.57.07.83 0-.3.73.41 1.22 1.08 1.17a4.73 4.73 0 001.39 2.65c.26.5.25 1.38.65 1.59zm0-1.22v-1c.35.26.15.7 0 1zm-2.47-3.61c-.11 0-.22 0-.24-.1s.33-.11.24.1zm4.91.06c-.15-.13-.11-.15 0-.26.1.1.13.13 0 .26z"/>
    <path class="COW_BODY" d="M269.85 516.2c.1-.3.35-.74 0-1v1zM267.38 512.59c.09-.21-.18-.25-.24-.1s.13.11.24.1zM272.29 512.65c.13-.13.1-.16 0-.26-.11.11-.15.13 0 .26z"/>
    <path class="BROWN_WOOD" d="M183.97 394.75l.79 1.63-5.78-.71-11.28 2.09-12.7 8.31-11.42 2.08v-5.92l-16.96 3.15-14.19 7.61-20.77 31.45 78.56-7.92 22.5-37.03 14.19-8.99-22.94 4.25z" />
    <path class="BARN_WOOD" d="M179 395.67l-24-2.92v13.32l12.7-8.31 11.3-2.09z"/>
    <path class="BARN_BUILDOUT_WOOD" d="M184.76 396.38l-6.23-12.81-29.24-3.11c1 2 4.84 10.43 5.71 12.29l24.34 2.86-.36.06z"/>
    <path class="BARN_BUILDOUT_WOOD" d="M178.97 395.67l.37-.06-24.34-2.86 23.97 2.92z"/>
    <path class="BARN_BUILDOUT_WOOD" d="M179.34 395.61l-.37.06s.36-.06.37-.06z"/>

    
    <path class="BARN_BUILDOUT_WOOD_2" d="M153.72 390l-4.43-9.54-5.71 11.76v15.93l11.42-2.08v-13.32zM155 392.75l-1.28-2.75 1.28 2.75z"/>
    <path class="BARN_THIN_LINE" d="M220.59 402.61l-13.68-12.12-14.19 9-22.5 37-78.56 7.92 1.51 1.08h1.61l76.83-7.61 22.84-37.38 12.81-8.31L219.72 404c.73 2.51 18.7 35.79 16.26 38.07h3.81z" />
    <path class="BARN_WOOD" d="M219.72 404l-12.46-11.77-12.81 8.31-22.84 37.38-76.83 7.61v42.35c35-.07 106.47-.15 141.2-.12v-49.84z"/>
    <path class="BARN_DOORS" d="M217.99 453.48l-25.61-.69v34.96h25.61v-34.27zM211.95 404.4l-10.07-1.02v25.12l10.07.68V404.4z"/>
    
    <path class="GRASS_POOL" d="M1891.34 774.81c19.63-11.15-21.53-15-28.53-16.69-.27 2.1-31.47 2.12-22.78.52 11.74-16.77-33.56-14.49-42.38-17.76-9 2.71-94.57 2.94-70.83 20.46-13.61 1.71-27.94.38-40.11 9.23-30.52 11.2 46.71 13.6 35.69 17.49 1.76 4.16-2.27 3.58-5.33 2-81.1 17 23.55 24.62 46.19 14.61 2.34 2 15.88-6.76 11.36-8.85 17.22-.54 31.36-5.58 46.2-12.86 4.48 6.34 7.17-2.53 8.72 2.53-.37 4.83 7.75 7.42 11.48 4.79 17.98 11.79 127.03-7.55 50.32-15.47z" />
    <path class="COW_DARK_LEGS" d="M1833 691.68c-.28 5.23 10 12.38 12 17.25 4.53 13.53.4 29.5-6 41.8-1.07 1.83-6.28 4.74-5.31 6.63 1.66 3.26 11.57 1.39 14.59-.66 9.62-12.29 6.82-33.57 17.92-45.12.16-8.9-5.36-22.06-15.26-23.88-4.52-.7-13.52 2.59-17.94 3.98zM1735.52 718.88c6.32 17.31 10.78 6.43 15.92 27.2.86 1.89 4.07 5.22 4 7.3-.11 2.39-6.57 5.93-5.31 8 5 3.4 14.71-3.3 15.26-9.29.35-5.55-8-14.67-9.95-19.9-2.43-8.06-3-20-10-25.66-5.8.93-7.9 7.71-9.92 12.35z" />
    <path class="COW_BODY" d="M1898.73 748.07c.09-8.21-4.5-24.3-4.65-32.51-.06-3.17 2.26-9.58 1.33-12.6-3.48-5.57-10.67-10.88-11.94-17.92 2-32 13-84.64-36.49-79.61 24 4.87-1.45 38.07-7.41 50-6.5 7.61-17.59 9-27.6 9.5-11 1.32-16.33-3.5-18.25-13.87-2.78-6.52-9.92-9.94-14.47-15.37-13.14-13.39 21.89-17.23 27.26-25-9.76 1-29.43 1.35-39.15 2.65-6.71.89-19.79 4.84-26.54 5.31-7.63-1.46-29.18 1-33.17 2 .53 0-10.37.56-17.25 2.47a23.18 23.18 0 01-.34 3.36c1.26-1.44 5.8-.73 7.53-1.19 3.79-2.11 8.94-3.34 13.16-1.77 9.08 4-5.27 18.16-20.16 11.81 3.41 14.55-.62 17.53-6.38 29.33-.07 1.19 1.82 3.23 1.77 4.42a5.16 5.16 0 01-4.43 4.64l.23.22a13.43 13.43 0 01-6.61 4.19c4.28 7.41 5.49 15 7.27 22.8 5.47 10.25 15.75 21.93 28.53 20.56 1.93-.21 5.74-3.81 7.3-2.65 2.12 1.59-.85 8-.67 10.62s2.24 7.42 2 10c-1.4 7-6.42 15.77-9.95 21.89-.83 1-4.42 2.1-4 3.32 1.13 3.12 10.32 1.51 13.27 0 6.17-5.67 6.58-15.66 8.62-23.22 9.78-13 3.48-36.33 25.88-36.49 24.45-2.06 28.23 11.7 55.07.66 7.67-3.76 16-11.83 24.54-13.93 9.32-3.3 19.3-7.07 27.21 1.33 14.06 15 32 36.45 28.53 58.38-.93 2.91-9.3 6.54-8 9.29 1.74 3.58 12.94 2 15.93-.67 2.3-2.02 1.99-8.92 2.03-11.95zm-153.29-67.58c-3 .49-31.42-22-25.07-20 9.33 5.18 16.51 14.47 26.06 19.87.79.53-.72.19-.99.13zm8.5-2.9c-2.56 4.92-39.34-35.94-23.67-27.17a134.11 134.11 0 0023.09 24.1c.82.66 1.39 2.18.58 3.07z"/>
    
    <path class="COW_DARK_SPOTS" d="M1710.75 623.56c-4.23-1.57-9.36-.34-13.16 1.77-1.73.45-6.26-.25-7.53 1.19a23.18 23.18 0 00.34-3.36c1.85-.47 2.41-2.28 3.22-5 .94-3.74-3.42-1.87-3.42-1.87l-1.79 2.14c-2.24-7.31-26.4-8.11-24.31 1.09L1661 616c-4-1.27-2.29 5.15-.66 7a7.86 7.86 0 00-1.77 1c-6-.53-10.5-6-16.77-3.18-1 .32-5.22.63-5.44 1.7 1.76 9.14 13.09 13.77 21.79 11.61 1.66 10.3-.06 21.47 4.83 31.09-.47 3.54-1.35 8.82 4 8.44-.31.33-.63.68-1 1.07 2.13 3.65 10.45 6 15.71-.67l-.23-.22a5.16 5.16 0 004.43-4.64c0-1.19-1.84-3.23-1.77-4.42 5.76-11.77 9.8-14.84 6.38-29.33 15.02 6.28 29.32-7.96 20.25-11.89zM1746.42 680.35a176.54 176.54 0 01-23.2-18.69 8.07 8.07 0 00-4.63-1.36c6.41 5.38 20.89 19.98 27.83 20.05zM1753.36 674.52a134.11 134.11 0 01-23.09-24.1c-.66-.89-2-1.69-3.15-1.11-3.52 4.34 19.58 24.38 23.71 28 2.34 2.16 4.97-.67 2.53-2.79zM1847 605.43c-11.2-.72-28.35 4.19-40.47 5.31 10.13-1.02 30.24-5.14 40.47-5.31z" />
    <path class="COW_DARK_SPOTS" d="M1776.33 629c1.05 10 14 13.31 17.39 22.06 1.36 3.21 1.55 7 3.68 9.75 3.21 4.17 9.32 4.38 14.57 4.12 16.91.11 29.56-6.19 34.7-22.62 29.1-48.61-7.43-36-40.16-31.58-3.77 5.63-30.17 11.51-30.18 18.27z" />
    
    <path class="GRASS_DARKER" d="M1687.46 769.51c-2.49-2.42 4.76-7.83 5.39-10.85-13.63 7.54-3.44-6.25-7.4-4.48-2.58 4.51-2.36-4.85-3.15-.72 2.31 5.25-6 9.51-1.66 14.37-4.34-.52-4-12.52-3.27-16.68 2.57-11.59-2.22-1.16-3.65 4.08-.4 1.65 0 6.12-1.68 5.22-1.18-1.55-5.16-9.79-5.46-7.27 1.42 6.26 3.7 10.72 1.46 14.19-1.83 5.45-1 .09-1.82-3.14-.25-3.76-2.71-7-3.82-10.46-2.13-3.18.92 8.16.62 9.74-14.71-11.3 3 3.79-1.47 14.52 2.27.12 3.61-2.76 4.31-4.55.37 8.58 4.9 1.92 4.89-2.94 3.25 2.16 1.28 5.53 2.83 7.33 2.23-.1 4.53-2.36 5.43-3.07 2.62 1.36 1.67-5.2 3.62-6.42.9-2.15-2.36 17.6 3.89 4.68 2.31 12.57 6.37-8.28 7.35-12.51-.65-2.23-5.05 7.01-6.41 8.96zm-14.46-7.36a7.71 7.71 0 01.23-1.18c-.14.49.21 2.29-.23 1.18zm3 8.06c-2.23-1.33-2.58-2-2-4.54.25 1.21 3.44 6.05 1.93 4.54zm7.28-3.15a4.18 4.18 0 01-2.4.79c1.75-.74 3.27-5.49 2.33-.79zM1663 763.31s0-.06 0 0z" />
    <path class="GRASS_DARKER" d="M1652.7 761.55c4.56 10.15 3 9-5.77 4.9.44 2.1 9 13.78 9.25 6.52.41-.61 5.17 7.53 3.83-3-2.08-2.43-4.09-8.71-7.31-8.42z" />
    
    ${
      darkMode &&
      `
    <!-- LASER_EYES_LEFT -->
    <g id="LASER_EYES_LEFT" transform="matrix(1, 0, 0, 1, 357.93634, 650.758179)">
      <path class="laser_st0" d="M14.9,0.9C16.2,0.4,17.7,0,18.7,0c1,0,1.9,0.4,2.6,1c0.7,0.7,1.1,1.6,1.1,2.5c0,1-0.4,1.9-1.1,2.6 c-0.7,0.7-1.6,1.1-2.6,1.1c-1,0-2.6-0.4-3.8-0.9c-1.8-0.8-2.7-1.7-2.7-2.7C12.3,2.6,13.2,1.7,14.9,0.9z" style="fill: rgb(237, 225, 123);"/>
      <path class="laser_st0" d="M3.7,0L3.7,0c1,0,2.5,0.4,3.8,0.9c1.7,0.8,2.7,1.7,2.7,2.7c0,2.3-4.8,3.6-6.4,3.6c-1,0-1.9-0.4-2.6-1.1 C0.4,5.5,0,4.5,0,3.5C0,1.6,1.7,0,3.7,0z" style="fill: rgb(237, 225, 123);"/>
      <g class="laser_st1" style="opacity: 0.6;">
        <linearGradient id="SVGID_1_" gradientUnits="userSpaceOnUse" x1="-274.7376" y1="155.6649" x2="-162.8208" y2="39.7716" gradientTransform="matrix(-0.915491, -0.500146, -0.422954, 0.956956, -126.907295, -113.327878)">
          <stop offset="0" style="stop-color:#144769"/>
          <stop offset="1" style="stop-color:#EDE17B"/>
        </linearGradient>
        <polygon class="laser_st2" points="3.7,6.5 44.6,191 73.3,161.3 7.8,6.5 &#9;&#9;" style="fill: url(#SVGID_1_);"/>
        <linearGradient id="SVGID_2_" gradientUnits="userSpaceOnUse" x1="-297.2" y1="131.0881" x2="-192.8226" y2="23.0022" gradientTransform="matrix(-0.986501, -0.214651, -0.195456, 0.991184, -167.664297, -62.141196)">
          <stop offset="0" style="stop-color:#144769"/>
          <stop offset="1" style="stop-color:#EDE17B"/>
        </linearGradient>
        <polygon class="laser_st3" points="16.4,6.5 84.5,149.6 114.4,118.4 20.5,6.5 &#9;&#9;" style="fill: url(#SVGID_2_);"/>
      </g>
    </g>
    <!-- END - LASER_EYES_LEFT -->
    `
    }

    ${
      !darkMode &&
      `
    <!-- sunglasses-black-shine-right -->
    <path id="sunglasses-black-shine-right" class="COW_BODY" d="M1685.74 639.77c1.4-3.27.13-7.57-4.09-7.06 8.59-1.32 7.67 10.55-.39 9.41 1.74-.2 3.74-.63 4.48-2.35zm-18.66-.27c2.73-4.83 0-6.38-4.66-6.79h.76a11.25 11.25 0 016 1.77c1.32 3.45-1.84 8-5.67 7.69h-.67a5.43 5.43 0 004.24-2.67z">

    </path>
    <!-- END - sunglasses-black-shine-right -->

    <!-- sunglasses-black-right -->
    <path id="sunglasses-black-right" d="M1655.2 633.81v-2.35l6.39-.35c7.61.18 6.15 1.82 11.08 1.93 4.92-.11 3.5-1.75 11.08-1.93l6.39.35v2.44c-1.63.74-.9 5.92-2.44 7.43-3.08 2.71-12.23 4-13.83-5.08a1.3 1.3 0 00-2.47 0c-1.49 9.08-10.8 7.81-13.81 5.09-1.61-1.65-.73-6.47-2.45-7.44zm26.7 8.34c7.54.5 8.06-10.74-.25-9.44 6.65-.7 5.83 9.92-.39 9.41.21.02.42.03.64.03zm-18.42 0c3.83.27 7-4.24 5.67-7.69a11.27 11.27 0 00-6-1.77h-.76a11.15 11.15 0 015.41 1.75c1.24 3.2-1.5 7.53-5 7.66.2.04.46.05.68.05z" style="">
    </path>
    <!-- END - sunglasses-black-right -->
    `
    }

    <path class="GRASS_POOL" d="M585.33 471.16s-.01-.04 0 0zM392.33 472.16s-.01-.03 0 0zM787.24 481.16a31.08 31.08 0 011.6-9.09c-12.94 9.43-2.09 16.12-12.88 4.45 0 0 .73 5.64.07 7.34 0 0-7.15-2.89-7.52-12.21-4.83 9 3.35 14.57-7.9 2.33 0 0 .42 6-1 8.39 0 0-7.51.16-7.67-8.15a9.38 9.38 0 00-2.53 6.94s-2.33-5.23-5.24-6.25c0 0 1.41 5.73-.32 7.61 0 .27-6.11-3.44-6-9.47-.22-6.95-3 3.62-2.39 7.56 0 0-3.22-7.6-5.77-8.94 0 0 1.77 7.91.07 9.64 0 .46-6.86.31-8.08-6.49-2-7.93-2.15 5.86-.19 7.7a10.7 10.7 0 01-4.9-10.16s-3.25 6.22-.76 9.86c-6.35-2.88-3.62-13-6.93-1 0 0-1-5.6-3.37-8.52 0 0 .07 8.84-1.77 10.08 0 0-4-.21-4.33-7.09 0 0-3.68 2.32-2.25 7.41 0 0-4.91-3.83-4.17-9.09 0 0-3.13 2.16-2.58 7.44-.36-.61-3.26-5.7-1.57-7.46a8.37 8.37 0 00-1.78 1.71 8.4 8.4 0 00-1.79-1.71c1.69 1.67-1.2 7-1.55 7.47.53-5.29-2.6-7.47-2.6-7.47.76 5.28-4.15 9.16-4.15 9.16 1.42-5.13-2.27-7.48-2.27-7.48-.3 7-4.31 7.2-4.31 7.2-1.84-1.26-1.8-10.25-1.8-10.25-2.35 3-3.34 8.68-3.34 8.68-.75-1.27-1.77-6.59-1.77-6.59-1.72 6.28-5.16 7.66-5.16 7.66 2.48-3.75-.78-10.13-.78-10.13a11.08 11.08 0 01-4.88 10.46c.77-.74 1.2-3.36 1.34-5.79-.26-13.12-1.12 7.23-9.61 4.56-1.71-1.8 0-10 0-10-2.55 1.36-5.75 9.3-5.74 9.3.59-4.11-2.23-15.2-2.42-7.92.22 6.24-6 10.28-5.93 9.94-1.73-2-.35-8-.34-8-2.91 1-5.22 6.59-5.22 6.6a10.43 10.43 0 00-2.56-7.39c-.12 8.82-7.63 8.66-7.64 8.67-1.42-2.56-1-9-1-9-2.68 1.83-6.33 8.48-6.32 8.48.66-7.42-1.59-11.07-1.59-11.07-.33 10-7.45 13.17-7.45 13.17-.68-1.85 0-8 0-8-1.35.91-2.86 3.12-4 5a29.42 29.42 0 011.56-8.09 24.54 24.54 0 00-4.8 4.64 26.36 26.36 0 00-5.7-6.53 41 41 0 011.65 11 17.18 17.18 0 00-4-4.65s.73 5.64.07 7.34c0 0-7.15-2.89-7.52-12.21-4.83 9 3.35 14.57-7.89 2.33 0 0 .41 6-1 8.39 0 0-7.51.16-7.67-8.15a9.43 9.43 0 00-2.53 6.94s-2.33-5.23-5.24-6.25c0 0 1.41 5.73-.32 7.61 0 .27-6.11-3.44-6-9.47-.22-6.95-3 3.62-2.39 7.56 0 0-3.22-7.6-5.77-8.94 0 0 1.78 7.91.07 9.64 0 .46-6.86.31-8.08-6.49-2-7.93-2.15 5.86-.19 7.7a10.7 10.7 0 01-4.9-10.16s-3.25 6.22-.76 9.86c0 0-3.44-1.32-5.18-7.47 0 0-1 5.2-1.75 6.45 0 0-1-5.6-3.37-8.52 0 0 .07 8.84-1.77 10.08 0 0-4-.21-4.32-7.09 0 0-3.69 2.32-2.25 7.41 0 0-4.92-3.83-4.18-9.09 0 0-3.13 2.16-2.58 7.44-.37-.63-3.26-5.69-1.57-7.46a8.37 8.37 0 00-1.78 1.71 8.4 8.4 0 00-1.79-1.71c1.69 1.67-1.2 7-1.55 7.47.54-5.29-2.6-7.47-2.6-7.47.76 5.28-4.15 9.16-4.15 9.16 1.42-5.13-2.27-7.48-2.27-7.48-.3 7-4.31 7.2-4.31 7.2-1.84-1.26-1.8-10.25-1.8-10.25-2.34 3-3.34 8.68-3.34 8.68-.75-1.27-1.77-6.59-1.77-6.59-1.72 6.28-5.16 7.66-5.16 7.66 2.48-3.75-.78-10.13-.78-10.13a11.08 11.08 0 01-4.88 10.46c.77-.74 1.21-3.36 1.34-5.79-.26-13.12-1.12 7.23-9.61 4.56-1.71-1.8 0-10 0-10-2.54 1.36-5.75 9.3-5.74 9.3.59-4.11-2.23-15.2-2.42-7.92.22 6.24-6 10.28-5.92 9.94-1.74-2-.36-8-.35-8-2.91 1-5.22 6.59-5.22 6.6a10.43 10.43 0 00-2.56-7.39c-.12 8.82-7.63 8.66-7.64 8.67-1.42-2.56-1-9-1-9-2.68 1.83-6.33 8.48-6.32 8.48.66-7.42-1.59-11.07-1.59-11.07-.33 10-7.45 13.17-7.45 13.17-.68-1.85 0-8 0-8a16.14 16.14 0 00-3.67 4.48 29.12 29.12 0 011.48-7.28 24.86 24.86 0 00-4.81 4.66 25.9 25.9 0 00-5.91-6.88 41 41 0 011.65 11 16.57 16.57 0 00-3.81-4.32s.73 5.64.07 7.35c0 0-7.15-2.89-7.52-12.21-4.83 9 3.35 14.57-7.9 2.33 0 0 .41 6-1 8.39 0 0-7.51.15-7.67-8.16a9.4 9.4 0 00-2.53 6.95s-2.33-5.23-5.24-6.25c0 0 1.41 5.73-.32 7.61 0 .27-6.11-3.44-6-9.47-.21-6.95-3 3.61-2.38 7.55 0 0-3.22-7.59-5.77-8.93 0 0 1.77 7.91.07 9.64 0 .46-6.86.3-8.08-6.49-2-7.94-2.15 5.86-.19 7.7a10.7 10.7 0 01-4.9-10.16s-3.25 6.21-.76 9.86c0 0-3.44-1.32-5.18-7.47 0 0-1 5.2-1.75 6.45 0 0-1-5.6-3.37-8.52 0 0 .07 8.83-1.77 10.08 0 0-4-.21-4.33-7.09 0 0-3.68 2.32-2.25 7.4 0 0-4.91-3.82-4.17-9.08 0 0-3.13 2.16-2.58 7.43-.31-.41-3.28-5.92-1.57-7.45a8.37 8.37 0 00-1.78 1.71 8.45 8.45 0 00-1.79-1.72c1.7 1.68-1.2 7-1.55 7.48.53-5.29-2.6-7.47-2.6-7.47.76 5.28-4.15 9.15-4.15 9.16 1.55-5.28-2.13-7.61-2.13-7.61-.3 6.95-4.31 7.19-4.31 7.2-1.84-1.26-1.8-10.26-1.8-10.26-2.35 3-3.34 8.69-3.34 8.69-.76-1.27-1.77-6.59-1.77-6.59-1.72 6.28-5.16 7.65-5.16 7.66 2.48-3.75-.78-10.14-.78-10.14A11.08 11.08 0 01267 485c.76-.75 1.2-3.36 1.34-5.79-.26-13.13-1.12 7.23-9.61 4.56-1.71-1.8 0-10 0-10-2.55 1.36-5.75 9.3-5.74 9.3.59-4.11-2.23-15.2-2.42-7.93.22 6.25-6 10.29-5.93 9.95-1.73-2-.35-8-.34-8-2.91 1-5.22 6.6-5.22 6.6a10.48 10.48 0 00-2.56-7.39c-.12 8.83-7.63 8.67-7.64 8.67-1.42-2.56-1.05-9-1-9-2.68 1.83-6.33 8.47-6.32 8.48.66-7.42-1.59-11.07-1.6-11.07-.32 10-7.44 13.16-7.44 13.17-.68-1.86 0-8 0-8-2.48 1.68-5.54 7.8-5.54 7.81 1.16-3.9-4.4-7.72-2.78-10.84a16.2 16.2 0 00-1.4 1.1 26 26 0 00-3.22-3.1c3.25 4.23-3.16 8.83-2.69 13.63 0 0-3.09-5.62-5.58-7.19 0 0 .74 5.64.07 7.34 0 0-7.14-2.89-7.52-12.21-4.82 9 3.36 14.57-7.89 2.33 0 0 .41 6-1 8.4 0 0-7.51.15-7.68-8.16a9.44 9.44 0 00-2.53 6.95s-2.33-5.24-5.24-6.25c0 0 1.41 5.73-.31 7.6 0 .27-6.12-3.43-6-9.47-.21-6.94-3 3.62-2.38 7.56 0 0-3.23-7.59-5.78-8.93 0 0 1.78 7.91.08 9.64 0 .45-6.86.3-8.08-6.49-2-7.94-2.16 5.86-.19 7.69a10.67 10.67 0 01-4.86-10.18s-3.24 6.21-.75 9.85c0 0-3.44-1.31-5.18-7.47 0 0-1 5.21-1.75 6.46 0 0-1-5.6-3.37-8.53 0 0 .07 8.84-1.77 10.09 0 0-4-.22-4.33-7.09 0 0-3.69 2.32-2.25 7.4 0 0-4.92-3.82-4.17-9.09 0 0-3.13 2.17-2.59 7.44-.34-.56-3.27-5.72-1.56-7.45a7.89 7.89 0 00-1.79 1.7 8.37 8.37 0 00-1.78-1.71c1.69 1.67-1.21 7-1.55 7.47.53-5.28-2.6-7.46-2.61-7.46.76 5.28-4.15 9.15-4.14 9.16 1.42-5.13-2.27-7.48-2.27-7.48-.3 6.95-4.31 7.19-4.31 7.2C83.93 485 84 476 84 476c-2.35 3-3.35 8.69-3.35 8.69-.75-1.28-1.77-6.6-1.77-6.6-1.72 6.29-5.15 7.66-5.15 7.66 2.48-3.74-.78-10.13-.79-10.13a11.08 11.08 0 01-4.87 10.46c.76-.74 1.2-3.36 1.33-5.79-.26-13.12-1.11 7.24-9.6 4.57-1.71-1.81 0-10 0-10-2.55 1.37-5.75 9.3-5.75 9.31.59-4.12-2.23-15.2-2.41-7.93.22 6.25-6 10.29-5.93 10-1.74-2-.35-8-.35-8-2.9 1.05-5.21 6.6-5.21 6.6a10.46 10.46 0 00-2.56-7.39C37.48 486.16 30 486 30 486c-1.43-2.56-1-9-1-9-2.67 1.83-6.32 8.47-6.32 8.48.66-7.42-1.59-11.08-1.59-11.08-.32 10-7.45 13.17-7.45 13.18-.67-1.86 0-8 0-8-2.47 1.68-5.54 7.8-5.53 7.8.65-6.52-7.39-12.83-7.4-12.83C2.83 478.16 3 492.33-2 494.7c66.34-5.53 729-9.16 793.7-4.36-.03 0-4.7-3.64-4.46-9.18z" />
    <path class="COW_DARK_LEGS" d="M2055.35 538c-1.46.24-3.27 3-4.5 3.86.08 1 1.63 2.58 1.93 3.54a51.65 51.65 0 01.48 7.57c.58 1.85-2.21 2.6-2.25 3.86 7.87 1.88 4.41-10.09 4.82-14.48.43-1.32 2.31-2.73.94-4.09a3.07 3.07 0 00-1.42-.26zM2024.33 549.22c.23 3.59-1.61 7.4-2 10.66 5.42.15 3-8.91 5.57-12a9.23 9.23 0 01-3.57 1.34z" />
    <path class="COW_BODY" d="M2066.3 552.48c-1.38-4.05-.85-8.72-1.93-12.88.27-7.13 2.13-16.92-4.83-21.57-4.41-.67-10 1-14.49 1.29-7.72.4-16.63.5-23.5 4.51-5.57 4.15-7.28 11.67-11.1 17.3 2.79-2.71 2.2 3.26 1 4.43-.43.48-2.18.64-2.25 1.28 1 1.64 3.92 2.12 3.94 4.61 2.79.15 4.23-3.11 6.52-3.8 1.37-.15 3.28 1.92 4.71 1.57 2.16-.05 3.74-1.87 5.27-2.22 1.28 1.45.46 5.12.64 7.08-.13 2.91-1.69 6.36-1.93 9 4.78.24 3.57-7.5 4.83-10.62 3.43-5 1-4.12 1.93-8.05 1.2-1.09 4.82.68 6.44.64a20.21 20.21 0 004.18-.64 27.64 27.64 0 005.16-2.58c1.23-.82 3-3.62 4.5-3.86 3.45-.16 4.45 3.57 5.48 6.12 3.41 3.64.89 5.32 3.54 9 .29 1.26-1.42 4.47-.33 5.15 2.84.23 2.72-3.73 2.22-5.76z"/>
    <path class="COW_DARK_SPOTS_2" d="M2013.1 551.45c0-2.49-2.92-3-3.94-4.61 1.42-1.38 2.85-.65 3.22-3.7.5-5.67-2.64-.8-4.35.32-2.42-.53-3.73 1.87-4.35 3.86a7.92 7.92 0 00-1.44 5c.61 2.84-1.63 5.55-1.77 8.2 1 1.57 2.87 1.06 4.18.16a5.68 5.68 0 004.51-1.6c.47-.56.54-2.15 1-2.74 1.54-1.16 3.52-2.59 2.94-4.89z"/>


    ${
      darkMode &&
      `
    <linearGradient id="gradient-1" gradientUnits="userSpaceOnUse" x1="-274.7376" y1="155.6649" x2="-162.8208" y2="39.7716" gradientTransform="matrix(0.224285, -1.449944, -1.364279, 0.612167, 329.520513, -252.369008)">
      <stop offset="0" style="stop-color:#144769"/>
      <stop offset="1" style="stop-color:#EDE17B"/>
    </linearGradient>
    <linearGradient id="gradient-2" gradientUnits="userSpaceOnUse" x1="-297.2" y1="131.0881" x2="-192.8226" y2="23.0022" gradientTransform="matrix(0.468845, -1.409545, -1.460614, 0.400625, 345.613749, -271.919477)">
      <stop offset="0" style="stop-color:#144769"/>
      <stop offset="1" style="stop-color:#EDE17B"/>
    </linearGradient>
      
    <!-- LASER_EYES_RIGHT -->
    <g id="LASER_EYES_RIGHT" transform="matrix(1, 0, 0, 1, 1442.211426, 633.382874)">

      <path class="laser_r_st0" d="M226.6,0.9c-1.3-0.6-2.8-0.9-3.8-0.9c-1,0-1.9,0.4-2.6,1c-0.7,0.7-1.1,1.6-1.1,2.5c0,1,0.4,1.9,1.1,2.6 c0.7,0.7,1.6,1.1,2.6,1.1c1,0,2.6-0.4,3.8-0.9c1.8-0.8,2.7-1.7,2.7-2.7C229.3,2.6,228.3,1.7,226.6,0.9z" style="fill: rgb(237, 225, 123);"/>
      <path class="laser_r_st0" d="M237.9,0L237.9,0c-1,0-2.5,0.4-3.8,0.9c-1.7,0.8-2.7,1.7-2.7,2.7c0,2.3,4.8,3.6,6.4,3.6c1,0,1.9-0.4,2.6-1.1 c0.7-0.7,1.1-1.7,1.1-2.6C241.5,1.6,239.8,0,237.9,0z" style="fill: rgb(237, 225, 123);"/>
      <g class="laser_r_st1" style="opacity: 0.6;">
        <linearGradient id="gradient-1" gradientUnits="userSpaceOnUse" x1="48.6924" y1="236.0661" x2="254.6583" y2="22.7822">
          <stop offset="0" style="stop-color:#144769"/>
          <stop offset="1" style="stop-color:#EDE17B"/>
        </linearGradient>
        <polygon class="laser_r_st2" points="237.8,6.5 67.7,254.4 39,224.8 233.7,6.5 &#9;&#9;" style="fill: url(#gradient-1);"/>
        <linearGradient id="gradient-2" gradientUnits="userSpaceOnUse" x1="14.3578" y1="198.929" x2="212.2368" y2="-5.9807">
          <stop offset="0" style="stop-color:#144769"/>
          <stop offset="1" style="stop-color:#EDE17B"/>
        </linearGradient>
        <polygon class="laser_r_st3" points="225.2,6.5 29.9,213.9 0,182.7 221.1,6.5 &#9;&#9;" style="fill: url(#gradient-2);"/>
      </g>
    </g>
    <!-- END - LASER_EYES_RIGHT -->
    `
    }

  </g>
</svg>
`
  // return Buffer.from(image).toString('base64')
  return btoa(unescape(encodeURIComponent(image)))
}

export function cowSwapLogo(darkMode: boolean): string {
  const darkModeLogo = `
  <svg fill="none" height="54" viewBox="0 0 169 54" width="169" xmlns="http://www.w3.org/2000/svg">
    <g fill="#cae9ff">
      <path d="m70.6953 11.9145c.648-.5513 1.758-.8273 3.3307-.8273h13.6604c1.5747 0 2.8513-1.27312 2.8513-2.84362 0-1.57051-1.2766-2.84368-2.8513-2.84368h-13.4272c-7.4651.00001-11.1977 3.02465-11.1977 9.0739v.2068c0 2.9645.9112 5.2005 2.7347 6.7084 1.8229 1.5082 4.6438 2.262 8.463 2.262h13.4271c1.5748 0 2.8513-1.2731 2.8513-2.8436s-1.2765-2.8437-2.8513-2.8437h-13.6603c-1.5551 0-2.6613-.2755-3.3179-.8272-.657-.5513-.985-1.3785-.985-2.4817v-.2068c0-1.1376.324-1.9817.9722-2.5335z" />
      <path d="m115.69 5.47715-3.248 5.61045h1.631c1.572 0 2.683.2759 3.331.8272.648.5519.972 1.396.972 2.5335v.2069c0 1.1031-.329 1.9304-.985 2.4816-.657.5517-1.763.8273-3.318.8273h-5.612l-3.292 5.6873h8.671c3.818 0 6.639-.7538 8.463-2.2621 1.823-1.5079 2.735-3.7439 2.735-6.7083v-.2069c0-5.52373-3.123-8.51716-9.348-8.99695z" />
      <path d="m109.885 11.0872 3.293-5.68729h-8.383c-7.4652 0-11.1978 3.02464-11.1978 9.07389v.2068c0 2.9645.9112 5.2005 2.7347 6.7084 1.4641 1.2115 3.5837 1.9275 6.3361 2.1658l3.237-5.5911h-1.343c-1.555 0-2.662-.2755-3.318-.8272-.657-.5513-.985-1.3785-.985-2.4817v-.2068c0-1.1376.324-1.9817.972-2.5335.648-.5513 1.758-.8273 3.331-.8273" />
      <path d="m165.085 5.39991c-1.089 0-2.106.53988-2.714 1.44028l-3.223 4.77391c-1.229 1.8202-3.873 1.9357-5.257.2296l-3.44-4.24178c-1.309-1.6143-3.778-1.6143-5.087 0l-3.44 4.24178c-1.384 1.7061-4.028 1.5906-5.257-.2296l-3.223-4.77391c-.608-.9004-1.625-1.44028-2.714-1.44028-2.631 0-4.185 2.94038-2.699 5.10549l8.05 11.7262c1.24 1.8064 3.877 1.9062 5.251.1988l4.024-5.0019c1.31-1.6275 3.793-1.6275 5.103 0l4.024 5.0019c1.374 1.7074 4.011 1.6076 5.251-.1988l8.05-11.7262c1.486-2.16511-.068-5.10549-2.699-5.10549z" />
      <path d="m69.3984 48.76c3.0885 0 5.9801-1.7473 5.9801-5.0449 0-3.3469-2.5348-4.1836-5.5371-5.3525-2.2394-.8614-3.8391-1.4643-3.8268-3.187.0123-1.6734 1.5135-2.5963 3.1747-2.5963 1.3535 0 2.9285.5784 4.3558 1.7473l1.3166-1.698c-1.698-1.3536-3.6791-2.1041-5.6601-2.0918-3.0639.0123-5.4633 2.0549-5.4633 4.7373 0 3.0884 2.6947 4.2328 5.3402 5.2172 2.3871.8982 4.0113 1.4396 4.0113 3.4576 0 1.7103-1.4765 2.7316-3.6668 2.7316-1.7472 0-3.6667-.7752-4.971-2.3748l-1.3905 1.6858c1.7842 1.9072 4.0975 2.7685 6.3369 2.7685z" />
      <path d="m92.7158 36.3446-3.1254 9.167h-.0492l-2.8301-9.167h-1.7718l-2.7932 9.1547h-.0492l-3.1254-9.1547h-2.0795l4.2574 12.2555h1.8826l2.7686-8.9333h.0492l2.7563 8.9333h1.9318l4.2574-12.2555z" />
      <path d="m106.189 36.3446v1.8088h-.049c-1.021-1.2797-2.535-1.9565-4.208-1.9565-3.4699 0-6.0047 2.7317-6.0047 6.3493 0 3.7652 2.6333 6.2138 6.0167 6.2138 1.809 0 3.31-.7875 4.307-2.1041h.025v1.9442h1.956v-12.2678zm-4.048 10.5451c-2.4976 0-4.1342-1.858-4.1342-4.3313 0-2.7316 1.8211-4.5035 4.1592-4.5035 2.35 0 4.097 1.9811 4.097 4.5035 0 2.5963-1.919 4.3313-4.122 4.3313z" />
      <path d="m118.285 36.1969c-1.661 0-3.15.6768-4.171 1.9565h-.05v-1.8088h-2.042v17.2389h2.03v-6.7922h.049c.985 1.2427 2.437 1.981 4.172 1.981 3.383 0 6.017-2.4609 6.017-6.2139 0-3.6298-2.535-6.3615-6.005-6.3615zm-.209 10.7051c-2.166 0-4.085-1.735-4.085-4.3312 0-2.5225 1.747-4.5036 4.06-4.5036 2.326 0 4.147 1.7719 4.147 4.5036 0 2.4732-1.637 4.3312-4.135 4.3312z" />
      <path d="m57.9096 4.98962c-.5327-3.74572-12.5029-1.54797-15.7031-.96045-.2551.04688-.4543.08344-.5879.10602-.0926.01562-.1792-.06226-.1604-.15283.184-.90619.3169-3.356375-1.4475-3.8868354-1.128-.3394196-1.872.2868004-2.3135.9185754-.1975.28345-.7891 1.50873-1.1567 2.35931-.1981.45935-.6594 1.13055-1.1665 1.11841-2.1263-.65106-4.2623-.97668-6.3982-.97668-2.1357 0-4.272.32562-6.3985.97668-.5068.01215-.9683-.65906-1.1667-1.11841-.3674-.85059-.9587-2.07587-1.1565-2.35931-.4414-.631705-1.185-1.257995-2.3132-.9185754-1.7649.5304604-1.6318 2.9806454-1.4475 3.8868354.0185.09058-.068.1684-.1609.15283-.1331-.02252-.332-.05908-.5865-.10583-3.1984-.58729-15.171318-2.7859-15.7045278.96026-.5459002 3.83607 4.3864678 9.12628 9.5476078 11.50388.27246.1255.51442.2984.75672.4716.2007.1434.4015.2869.6202.4039.8125.4348 1.2969 1.52 1.178 2.4989v13.7058c4.0696-2.8157 10.0517-4.5679 16.8318-4.5679 6.7802 0 12.7622 1.7522 16.832 4.568v-13.7059c-.1192-.9789.365-2.0641 1.1773-2.4989.2193-.1171.4206-.2609.6216-.4046.2419-.1729.4835-.3455.7555-.4709 5.1611-2.3775 10.0941-7.66775 9.5474-11.50388zm-30.591 14.38128c-.2119 1.1196-2.1001 1.8213-3.646 2.2134-1.2339.3052-2.4986.4585-3.7749.4585-.3228 0-.646-.0098-.9697-.0293-.5-.0308-.9292-.1201-1.3121-.2734-.7519-.3003-1.4023-.8233-1.8798-1.5118-.669-.9336-.9273-1.9804-.7393-3.0161.1831-1.0322.7886-1.9267 1.7495-2.5835.6734-.4765 1.4639-.7485 2.2749-.7783.418-.0146.8496.0464 1.3272.1851 1.5405.4477 2.9897 1.1201 4.3066 1.998 1.3237.8926 2.8574 2.1904 2.6665 3.3198zm14.8887.8687c-.4688.6767-1.1192 1.1997-1.8721 1.5009-.3828.1529-.8115.2422-1.3115.273-.3238.0195-.648.0293-.9707.0293-1.2759 0-2.5396-.1533-3.7691-.4575-1.5503-.3926-3.438-1.0948-3.6513-2.2139-.1924-1.1479 1.3403-2.4453 2.6601-3.335 1.3228-.8818 2.772-1.5542 4.3115-2.0009.4756-.1387.9038-.2007 1.3247-.1851.8125.0298 1.6031.3018 2.2886.7871.9497.6485 1.5547 1.5435 1.7378 2.5791.1875 1.0322-.0708 2.0786-.748 3.023z" />
    </g>
      <path d="m23.6526 17.5286c-1.1602-.7734-2.4424-1.3681-3.8072-1.7646-.2666-.0777-.4975-.1157-.7036-.1157-.019 0-.0381.0004-.0566.0009-.4585.0166-.9121.1748-1.3111.4571-.5805.3969-.9052.8598-1.0053 1.4238-.1026.5644.041 1.1064.438 1.6611.2837.4087.6538.708 1.0776.8775.2022.081.4482.1294.7524.1479 1.4229.0874 2.835-.041 4.1983-.3784 1.2373-.3135 1.8672-.6294 2.1621-.8184-.2119-.2758-.6943-.7827-1.7446-1.4912z" fill="#ffcf56" />
      <path d="m40.1897 16.115c-.4112-.291-.8648-.4492-1.3247-.4658-.2188-.0039-.4673.0298-.7578.1143-1.3643.396-2.6465.9907-3.8125 1.7681-1.0469.706-1.5284 1.2119-1.7403 1.4882.2954.189.9263.5049 2.167.8194 1.3579.3364 2.77.4638 4.1929.3774.3047-.0185.5508-.0669.7524-.1474.4239-.1695.794-.4693 1.0694-.8667.4057-.566.5493-1.1075.4472-1.6685-.1001-.5679-.4248-1.0308-.9936-1.419z" fill="#ffcf56" />
      <path d="m28.9758 31.286c-11.0748 0-20.05225 5.0846-20.05225 11.3571 0 6.2724 8.97745 11.3569 20.05225 11.3569s20.0525-5.0846 20.0525-11.3569c0-6.2724-8.9779-11.3571-20.0525-11.3571zm-9.491 12.5177c-1.7159.8235-3.3137 0-3.6201-1.8675-.3359-2.0008 2.4055-6.7561 3.0361-3.1603.3609 2.0571 1.4339 1.2915 2.2896.6811.6398-.4565 1.158-.8261 1.1653.1367-.094 1.8167-1.1972 3.4351-2.8709 4.21zm22.6018-1.8675c-.3068 1.8675-1.9046 2.691-3.6203 1.8675-1.6737-.7749-2.7771-2.3933-2.8704-4.21.0071-.9628.525-.5932 1.1647-.1368.8555.6104 1.9286 1.3762 2.2898-.681.6305-3.5958 3.3716 1.1595 3.0362 3.1603z" fill="#cae9ff" />
   </svg>`

  // Please note, this Light Mode logo is using a different blue from the branding kit.
  // Instead it uses #152943 to adapt to the existing CoW Swap theme colors.
  const lightModeLogo = `
  <svg fill="none" height="54" width="169" xmlns="http://www.w3.org/2000/svg">
  <g fill="#152943">
    <path clip-rule="evenodd" d="m42.206 4.03c3.2-.588 15.17-2.786 15.704.96.546 3.836-4.387 9.126-9.548 11.504-.272.125-.513.297-.755.47-.201.144-.402.288-.622.405-.812.435-1.296 1.52-1.177 2.499v13.706c-4.07-2.816-10.052-4.568-16.832-4.568s-12.762 1.752-16.832 4.568v-13.706c.119-.979-.366-2.064-1.178-2.499a5.723 5.723 0 0 1 -.62-.404c-.242-.173-.484-.346-.757-.471-5.161-2.378-10.093-7.668-9.548-11.504.534-3.746 12.507-1.548 15.705-.96.254.046.453.083.587.105.092.016.179-.062.16-.153-.184-.906-.317-3.356 1.448-3.886 1.128-.34 1.872.286 2.313.918.198.284.79 1.509 1.157 2.36.198.459.66 1.13 1.166 1.118a21.77 21.77 0 0 1 6.399-.977c2.136 0 4.272.326 6.398.977.507.012.968-.66 1.167-1.119.367-.85.959-2.075 1.156-2.359.442-.632 1.186-1.258 2.314-.918 1.764.53 1.631 2.98 1.447 3.886-.018.09.068.169.16.153.134-.022.334-.059.588-.106zm-15.772 15.172c.06-.347-.508-1.226-2.278-2.42a14.76 14.76 0 0 0 -4.06-1.883 3.329 3.329 0 0 0 -1.042-.15c-.643.024-1.26.24-1.8.622-.721.492-1.22 1.15-1.371 2-.155.85.086 1.637.593 2.343.374.54.878.951 1.474 1.19.327.13.68.188 1.032.21 1.499.091 3.013-.043 4.47-.403 2.078-.527 2.917-1.163 2.982-1.509zm13.567 1.702a3.267 3.267 0 0 0 1.475-1.19c.506-.706.747-1.492.593-2.342-.15-.85-.65-1.509-1.372-2.001a3.312 3.312 0 0 0 -1.8-.622 3.329 3.329 0 0 0 -1.042.15 14.755 14.755 0 0 0 -4.06 1.882c-1.77 1.195-2.336 2.074-2.278 2.421.066.346.904.982 2.983 1.509 1.456.36 2.97.494 4.47.403.351-.022.705-.08 1.031-.21z" fill-rule="evenodd" />
    <path clip-rule="evenodd" d="m8.924 42.643c0-6.272 8.977-11.357 20.052-11.357 11.074 0 20.052 5.085 20.052 11.357s-8.977 11.357-20.052 11.357-20.052-5.084-20.052-11.357zm6.94-.707c.307 1.868 1.905 2.691 3.62 1.868a4.93 4.93 0 0 0 2.872-4.21c-.008-.963-.526-.593-1.166-.137-.855.61-1.928 1.376-2.29-.681-.63-3.596-3.371 1.16-3.035 3.16zm22.602 1.868c1.716.823 3.314 0 3.62-1.868.336-2-2.405-6.756-3.036-3.16-.36 2.057-1.434 1.291-2.29.68-.639-.456-1.157-.825-1.164.138a4.927 4.927 0 0 0 2.87 4.21z" fill-rule="evenodd" />
    <path d="m70.695 11.915c.648-.552 1.758-.828 3.331-.828h13.66a2.847 2.847 0 0 0 2.852-2.843 2.848 2.848 0 0 0 -2.852-2.844h-13.426c-7.465 0-11.197 3.025-11.197 9.074v.207c0 2.964.91 5.2 2.734 6.708 1.823 1.508 4.644 2.262 8.463 2.262h13.427a2.847 2.847 0 0 0 2.852-2.843 2.848 2.848 0 0 0 -2.852-2.844h-13.66c-1.555 0-2.661-.276-3.318-.827-.657-.552-.985-1.379-.985-2.482v-.207c0-1.138.324-1.982.972-2.533zm44.995-6.438-3.248 5.61h1.631c1.572 0 2.683.277 3.331.828.648.552.972 1.396.972 2.533v.207c0 1.103-.329 1.93-.985 2.482-.657.552-1.763.827-3.318.827h-5.612l-3.292 5.688h8.671c3.818 0 6.639-.754 8.463-2.263 1.823-1.508 2.735-3.744 2.735-6.708v-.207c0-5.524-3.123-8.517-9.348-8.997zm-5.805 5.61 3.293-5.687h-8.383c-7.465 0-11.198 3.025-11.198 9.074v.207c0 2.964.911 5.2 2.735 6.708 1.464 1.212 3.584 1.928 6.336 2.166l3.237-5.591h-1.343c-1.555 0-2.662-.276-3.318-.827-.657-.552-.985-1.379-.985-2.482v-.207c0-1.138.324-1.982.972-2.533.648-.552 1.758-.828 3.331-.828m60.523-5.687c-1.089 0-2.106.54-2.714 1.44l-3.223 4.774c-1.229 1.82-3.873 1.936-5.257.23l-3.44-4.242a3.277 3.277 0 0 0 -5.087 0l-3.44 4.242c-1.384 1.706-4.028 1.59-5.257-.23l-3.223-4.774a3.274 3.274 0 0 0 -2.714-1.44c-2.631 0-4.185 2.94-2.699 5.105l8.05 11.727c1.24 1.806 3.877 1.906 5.251.198l4.024-5.001a3.277 3.277 0 0 1 5.103 0l4.024 5.002c1.374 1.707 4.011 1.607 5.251-.2l8.05-11.726c1.486-2.165-.068-5.105-2.699-5.105zm-95.687 43.36c3.089 0 5.98-1.747 5.98-5.045 0-3.347-2.534-4.183-5.537-5.352-2.239-.862-3.839-1.465-3.826-3.187.012-1.674 1.513-2.597 3.174-2.597 1.354 0 2.929.579 4.356 1.748l1.317-1.698c-1.698-1.354-3.68-2.104-5.66-2.092-3.064.012-5.464 2.055-5.464 4.737 0 3.089 2.695 4.233 5.34 5.217 2.388.899 4.012 1.44 4.012 3.458 0 1.71-1.477 2.732-3.667 2.732a6.488 6.488 0 0 1 -4.971-2.375l-1.39 1.686a8.61 8.61 0 0 0 6.336 2.768zm23.318-12.415-3.126 9.167h-.049l-2.83-9.167h-1.771l-2.793 9.154h-.05l-3.124-9.154h-2.08l4.256 12.255h1.883l2.769-8.933h.049l2.756 8.933h1.932l4.257-12.255h-2.08zm13.473 0v1.809h-.049c-1.021-1.28-2.535-1.957-4.208-1.957-3.47 0-6.005 2.732-6.005 6.35 0 3.765 2.634 6.213 6.017 6.213 1.809 0 3.31-.787 4.307-2.104h.025v1.944h1.956v-12.268zm-4.048 10.545c-2.498 0-4.134-1.858-4.134-4.331 0-2.732 1.82-4.504 4.159-4.504 2.35 0 4.097 1.981 4.097 4.504 0 2.596-1.919 4.33-4.122 4.33zm16.144-10.693c-1.661 0-3.15.677-4.171 1.956h-.05v-1.808h-2.042v17.239h2.03v-6.794h.049c.985 1.243 2.437 1.981 4.172 1.981 3.383 0 6.017-2.46 6.017-6.213 0-3.63-2.535-6.362-6.005-6.362zm-.209 10.705c-2.166 0-4.085-1.735-4.085-4.331 0-2.523 1.747-4.504 4.06-4.504 2.326 0 4.147 1.772 4.147 4.504 0 2.473-1.637 4.331-4.135 4.331z" />
  </g>
</svg>
  `

  return btoa(unescape(encodeURIComponent(darkMode ? darkModeLogo : lightModeLogo)))
}
